/*
 *******************************************************************************
 *
 *  Copyright 2024 RIEGL Laser Measurement Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 *******************************************************************************
 */
/*!
 *******************************************************************************
 *
 * \author  RIEGL LMS GmbH, Austria
 * \brief   Description of RIEGL RDB 2 database meta data items.
 * \version 2015-10-27/AW: Initial version
 * \version 2015-11-25/AW: Item "Geo Tag" added
 * \version 2016-10-27/AW: Item "Voxel Information" added
 * \version 2016-11-17/AW: Item "Voxel Information" updated
 * \version 2016-12-12/AW: Item "Range Statistics" added
 * \version 2017-03-08/AW: Item "Plane Patch Statistics" added
 * \version 2017-04-05/AW: Items "Atmosphere" and "Geometric Scale Factor" added
 * \version 2017-08-22/AW: Items for waveform sample block and value files added
 * \version 2017-10-24/AW: Item "Gaussian Decomposition" added
 * \version 2017-11-13/AW: Item "riegl.scan_pattern" updated
 * \version 2017-11-21/AW: Item "riegl.trajectory_info" added
 * \version 2018-01-11/AW: Item "riegl.beam_geometry" added
 * \version 2018-01-15/AW: Item "riegl.reflectance_calculation" added
 * \version 2018-01-15/AW: Item "riegl.near_range_correction" added
 * \version 2018-01-15/AW: Item "riegl.device_geometry" added
 * \version 2018-02-13/AW: Item "riegl.notch_filter" added
 * \version 2018-03-08/AW: Item "riegl.window_echo_correction" added
 * \version 2018-03-15/AW: Item "riegl.pulse_position_modulation" added
 * \version 2018-05-24/AW: Item "riegl.pixel_info" added
 * \version 2018-06-08/AW: Item "riegl.shot_info" added
 * \version 2018-06-08/AW: Item "riegl.echo_info" added
 * \version 2018-06-14/AW: Item "riegl.mta_settings" added
 * \version 2018-06-14/AW: Item "riegl.receiver_internals" added
 * \version 2018-06-14/AW: Item "riegl.device_output_limits" added
 * \version 2018-06-26/AW: Schema: replace "number" with "integer" if applicable
 * \version 2018-07-09/AW: Item "riegl.pose_estimation" added
 * \version 2018-07-09/AW: Item "riegl.pose_sensors" added
 * \version 2018-09-20/AW: Item "riegl.pointcloud_info" added
 * \version 2018-11-08/AW: Item "riegl.scan_pattern" updated
 * \version 2018-11-13/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-06/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-21/AW: Item "riegl.device_geometry" updated
 * \version 2019-04-15/AW: Item "riegl.point_attribute_groups" added
 * \version 2019-04-30/AW: Item "riegl.waveform_settings" added
 * \version 2019-10-03/AW: Item "riegl.angular_notch_filter" added
 * \version 2019-10-03/AW: Item "riegl.noise_estimates" added
 * \version 2019-10-25/AW: Item "riegl.window_analysis" added
 * \version 2019-11-06/AW: Item "riegl.georeferencing_parameters" added
 * \version 2019-11-27/AW: Item "riegl.plane_patch_matching" added
 * \version 2019-12-13/AW: Items for tie-/control objects added
 * \version 2019-12-19/AW: Items for tie-/control objects added
 * \version 2020-02-04/AW: Item "riegl.detection_probability" added
 * \version 2020-02-04/AW: Item "riegl.licenses" added
 * \version 2020-04-27/AW: Item "riegl.waveform_info" updated (schema+example)
 * \version 2020-09-03/AW: Item "riegl.reflectance_correction" added
 * \version 2020-09-10/AW: Item "riegl.device_geometry_passive_channel" added
 * \version 2020-09-25/AW: Item "riegl.georeferencing_parameters" updated
 * \version 2020-09-25/AW: Item "riegl.trajectory_info" updated
 * \version 2020-09-29/AW: Item "riegl.temperature_calculation" added
 * \version 2020-10-23/AW: Item "riegl.exponential_decomposition" added (#3709)
 * \version 2020-11-30/AW: Item "riegl.notch_filter" updated (schema)
 * \version 2020-12-02/AW: Item "riegl.georeferencing_parameters" updated (schema)
 * \version 2021-02-02/AW: Item "riegl.plane_slope_class_info" added (rdbplanes/#7)
 * \version 2021-02-16/AW: Item "riegl.device_output_limits" updated (schema, #3811)
 * \version 2021-03-03/AW: Item "riegl.exponential_decomposition" updated (schema, #3822)
 * \version 2021-03-03/AW: Item "riegl.waveform_averaging_settings" added (#3821)
 * \version 2021-04-01/AW: Item "riegl.voxel_info" updated (schema, #3854)
 * \version 2021-04-16/AW: Item "riegl.voxel_info" updated (schema, #3866)
 * \version 2021-09-30/AW: Item "riegl.waveform_info" updated (schema+example, #4016)
 * \version 2021-10-04/AW: Improved spelling of the descriptions of some items
 * \version 2021-11-04/AW: Rename "riegl.record_names" to "riegl.item_names" (#4034)
 * \version 2022-03-11/AW: Item "riegl.devices" added (#4162)
 * \version 2022-03-14/AW: Item "riegl.stored_filters" added (#4164)
 * \version 2022-09-20/AW: Fix typos in schema of "riegl.georeferencing_parameters"
 * \version 2022-09-30/AW: Item "riegl.system_description" added (#4368)
 * \version 2022-10-10/AW: Correction of typos in the titles of some entries
 * \version 2022-10-20/AW: Item "riegl.stored_filters" updated (example, #4164)
 * \version 2023-01-19/AW: Item "riegl.ttip_configuration" added (#4449)
 * \version 2024-09-26/AW: Item "riegl.dyntrig" added (#5310)
 *
 *******************************************************************************
 */

#ifndef RDB_354CFFB3_BDAA_4E38_98C8_9C09D0C0AD87
#define RDB_354CFFB3_BDAA_4E38_98C8_9C09D0C0AD87

#include <vector>
#include <string>
#include <cstdlib>
#include <cstdint>

namespace riegl {
namespace rdb {
namespace pointcloud {

// Meta data item definition version
const std::string RDB_META_DATA_ITEMS_VERSION = "1.1.54";
const std::string RDB_META_DATA_ITEMS_DATE = "2023-01-19";

// Meta data item states
const unsigned char RDB_STATUS_REQUIRED = 1; // mandatory item
const unsigned char RDB_STATUS_OPTIONAL = 2; // optional item

// Container record for meta data item details
struct MetaDataItemInfo
{
    std::string   name;
    std::string   title;
    std::string   description;
    unsigned char status;
    std::string   schema;
    std::string   example;

    operator const std::string&() const { return name; }
};

// Angular notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_ANGULAR_NOTCH_FILTER = {
    /* name        */ "riegl.angular_notch_filter",
    /* title       */ "Angular Notch Filter",
    /* description */ "Angular notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"angle\",\"range_mean\",\"amplitude_mean\"],\"$schema\":\"http://"
    "json-schema.org/draft-04/schema#\",\"description\":\"Angular notch filter "
    "parameters for window glass echoes\",\"type\":\"object\",\"properties\":{\"ang"
    "le\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"Angle [de"
    "g]\"},\"amplitude_mean\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"descr"
    "iption\":\"Mean amplitude [dB]\"},\"range_mean\":{\"type\":\"array\",\"items\":{\""
    "type\":\"number\"},\"description\":\"Mean range [m]\"}},\"title\":\"Angular "
    "Notch Filter\"}"
    ,
    /* example: */
    "{\"angle\":[14.0,15.0,16.0,17.0,18.0,19.0,20.0,21.0,22.0,23.0,24.0],\"amp"
    "litude_mean\":[3.780913,3.780913,3.480913,3.120913,2.850913,2.720913,2."
    "680913,2.610913,2.530913,2.570913,2.570913],\"range_mean\":[0.094,0.094,"
    "0.09075,0.08675,0.0815,0.0775,0.074,0.071,0.068,0.0675,0.06475]}"
};

// Atmospheric parameters
const MetaDataItemInfo RDB_RIEGL_ATMOSPHERE = {
    /* name        */ "riegl.atmosphere",
    /* title       */ "Atmosphere",
    /* description */ "Atmospheric parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"temperature\",\"pressure\",\"rel_humidity\",\"pressure_sl\",\"am"
    "sl\",\"group_velocity\",\"attenuation\",\"wavelength\"],\"$schema\":\"http://jso"
    "n-schema.org/draft-04/schema#\",\"description\":\"Atmospheric parameters\","
    "\"type\":\"object\",\"properties\":{\"pressure_sl\":{\"type\":\"number\",\"descript"
    "ion\":\"Atmospheric pressure at sea level "
    "[mbar]\"},\"amsl\":{\"type\":\"number\",\"description\":\"Height above mean sea "
    "level (AMSL) "
    "[m]\"},\"attenuation\":{\"type\":\"number\",\"description\":\"Atmospheric "
    "attenuation "
    "[1/km]\"},\"rel_humidity\":{\"type\":\"number\",\"description\":\"Relative "
    "humidity along measurement path "
    "[%]\"},\"wavelength\":{\"type\":\"number\",\"description\":\"Laser wavelength "
    "[nm]\"},\"pressure\":{\"type\":\"number\",\"description\":\"Pressure along "
    "measurment path "
    "[mbar]\"},\"temperature\":{\"type\":\"number\",\"description\":\"Temperature "
    "along measurement path "
    "[\\u00b0C]\"},\"group_velocity\":{\"type\":\"number\",\"description\":\"Group "
    "velocity of laser beam [m/s]\"}},\"title\":\"Atmospheric Parameters\"}"
    ,
    /* example: */
    "{\"pressure_sl\":970,\"amsl\":0,\"attenuation\":0.028125,\"rel_humidity\":63,\""
    "wavelength\":1550,\"pressure\":970,\"temperature\":7,\"group_velocity\":29971"
    "1000.0}"
};

// Laser beam geometry details
const MetaDataItemInfo RDB_RIEGL_BEAM_GEOMETRY = {
    /* name        */ "riegl.beam_geometry",
    /* title       */ "Beam Geometry",
    /* description */ "Laser beam geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"beam_exit_diameter\",\"beam_divergence\"],\"$schema\":\"http:/"
    "/json-schema.org/draft-04/schema#\",\"description\":\"Laser beam geometry "
    "details\",\"type\":\"object\",\"properties\":{\"beam_divergence\":{\"type\":\"numb"
    "er\",\"minimum\":0,\"description\":\"Beam divergence in far field [rad]\",\"ex"
    "clusiveMinimum\":false},\"beam_exit_diameter\":{\"type\":\"number\",\"minimum\""
    ":0,\"description\":\"Beam width at exit aperture "
    "[m]\",\"exclusiveMinimum\":false}},\"title\":\"Beam Geometry\"}"
    ,
    /* example: */
    "{\"beam_divergence\":0.0003,\"beam_exit_diameter\":0.0072}"
};

// List of control object type definitions
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_CATALOG = {
    /* name        */ "riegl.control_object_catalog",
    /* title       */ "Control Object Catalog",
    /* description */ "List of control object type definitions",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"types\"],\"description\":\"List of control object type defin"
    "itions\",\"definitions\":{\"rectangle\":{\"type\":\"object\",\"allOf\":[{\"$ref\":\""
    "#/definitions/common\"},{\"required\":[\"shape\",\"length\",\"width\"],\"type\":\""
    "object\",\"properties\":{\"shape\":{\"enum\":[\"rectangle\"],\"type\":\"string\"},\""
    "width\":{\"type\":\"number\",\"minimum\":0,\"description\":\"width in meters\",\"e"
    "xclusiveMinimum\":true},\"length\":{\"type\":\"number\",\"minimum\":0,\"descript"
    "ion\":\"length in "
    "meters\",\"exclusiveMinimum\":true}},\"description\":\"rectangle specific pr"
    "operties\"}],\"description\":\"rectangle\"},\"cylinder\":{\"type\":\"object\",\"al"
    "lOf\":[{\"$ref\":\"#/definitions/common\"},{\"required\":[\"shape\",\"diameter\","
    "\"height\"],\"type\":\"object\",\"properties\":{\"shape\":{\"enum\":[\"cylinder\"],\""
    "type\":\"string\",\"description\":\"shape identifier\"},\"height\":{\"type\":\"num"
    "ber\",\"minimum\":0,\"description\":\"height in meters\",\"exclusiveMinimum\":t"
    "rue},\"diameter\":{\"type\":\"number\",\"minimum\":0,\"description\":\"diameter "
    "in meters\",\"exclusiveMinimum\":true}},\"description\":\"cylinder specific "
    "properties\"}],\"description\":\"cylinder\"},\"round_corner_cube_prism\":{\"ty"
    "pe\":\"object\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"required\":[\"sh"
    "ape\",\"diameter\"],\"type\":\"object\",\"properties\":{\"shape\":{\"enum\":[\"round"
    "_corner_cube_prism\"],\"type\":\"string\",\"description\":\"shape "
    "identifier\"},\"offset\":{\"type\":\"number\",\"description\":\"offset in "
    "meters, e.g. reflector constant (optional)\"},\"diameter\":{\"type\":\"numbe"
    "r\",\"minimum\":0,\"description\":\"diameter in "
    "meters\",\"exclusiveMinimum\":true}},\"description\":\"round corner cube "
    "prism specific properties\"}],\"description\":\"round corner cube prism\"},"
    "\"circular_disk\":{\"type\":\"object\",\"allOf\":[{\"$ref\":\"#/definitions/commo"
    "n\"},{\"required\":[\"shape\",\"diameter\"],\"type\":\"object\",\"properties\":{\"sh"
    "ape\":{\"enum\":[\"circular_disk\"],\"type\":\"string\",\"description\":\"shape "
    "identifier\"},\"offset\":{\"type\":\"number\",\"description\":\"offset in "
    "meters, e.g. reflector constant (optional)\"},\"diameter\":{\"type\":\"numbe"
    "r\",\"minimum\":0,\"description\":\"diameter in "
    "meters\",\"exclusiveMinimum\":true}},\"description\":\"circular disk "
    "specific properties\"}],\"description\":\"circular disk\"},\"checkerboard2x2"
    "\":{\"type\":\"object\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"required"
    "\":[\"shape\",\"square_length\"],\"type\":\"object\",\"properties\":{\"shape\":{\"en"
    "um\":[\"checkerboard2x2\"],\"type\":\"string\",\"description\":\"shape identifie"
    "r\"},\"square_length\":{\"type\":\"number\",\"minimum\":0,\"description\":\"length"
    " of a square of the checkerboard in "
    "meters\",\"exclusiveMinimum\":true}},\"description\":\"checkerboard specific"
    " properties\"}],\"description\":\"checkerboard 2 by 2\"},\"chevron\":{\"type\":"
    "\"object\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"required\":[\"shape\""
    ",\"outside_edge_length\",\"thickness\"],\"type\":\"object\",\"properties\":{\"sha"
    "pe\":{\"enum\":[\"chevron\"],\"type\":\"string\",\"description\":\"shape identifie"
    "r\"},\"outside_edge_length\":{\"type\":\"number\",\"minimum\":0,\"description\":\""
    "length of the two outer edges in meters\",\"exclusiveMinimum\":true},\"thi"
    "ckness\":{\"type\":\"number\",\"minimum\":0,\"description\":\"thickness in "
    "meters\",\"exclusiveMinimum\":true}},\"description\":\"chevron specific prop"
    "erties\"}],\"description\":\"chevron\"},\"common\":{\"required\":[\"name\",\"shape"
    "\"],\"type\":\"object\",\"properties\":{\"surface_type\":{\"enum\":[\"retro_reflec"
    "tive_foil\",\"diffuse\"],\"type\":\"string\",\"description\":\"surface material "
    "type\"},\"shape\":{\"enum\":[\"rectangle\",\"checkerboard2x2\",\"chevron\",\"circu"
    "lar_disk\",\"cylinder\",\"sphere\",\"round_corner_cube_prism\"],\"type\":\"strin"
    "g\",\"description\":\"shape identifier\"},\"name\":{\"type\":\"string\",\"minLengt"
    "h\":3,\"description\":\"unique type "
    "identifier\"},\"description\":{\"type\":\"string\",\"description\":\"string "
    "describing the object\"}},\"description\":\"common object properties\"},\"sp"
    "here\":{\"type\":\"object\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"requ"
    "ired\":[\"shape\",\"diameter\"],\"type\":\"object\",\"properties\":{\"shape\":{\"enu"
    "m\":[\"sphere\"],\"type\":\"string\",\"description\":\"shape identifier\"},\"diame"
    "ter\":{\"type\":\"number\",\"minimum\":0,\"description\":\"diameter in "
    "meters\",\"exclusiveMinimum\":true}},\"description\":\"sphere specific prope"
    "rties\"}],\"description\":\"sphere\"}},\"type\":\"object\",\"properties\":{\"types"
    "\":{\"uniqueItems\":true,\"type\":\"array\",\"items\":{\"type\":\"object\",\"oneOf\":"
    "[{\"$ref\":\"#/definitions/rectangle\"},{\"$ref\":\"#/definitions/checkerboar"
    "d2x2\"},{\"$ref\":\"#/definitions/chevron\"},{\"$ref\":\"#/definitions/circula"
    "r_disk\"},{\"$ref\":\"#/definitions/cylinder\"},{\"$ref\":\"#/definitions/sphe"
    "re\"},{\"$ref\":\"#/definitions/round_corner_cube_prism\"}]}}},\"$schema\":\"h"
    "ttp://json-schema.org/draft-04/schema#\",\"title\":\"Control Object "
    "Catalog\"}"
    ,
    /* example: */
    "{\"comments\":[\"This file contains a list of control object types (aka. "
    "'catalog').\",\"Each type is described by an object,\",\"which must "
    "contain at least the following parameters:\",\"  - name: unique "
    "identifier of the type\",\"  - shape: one of the following supported "
    "shapes:\",\"      - rectangle\",\"      - checkerboard2x2\",\"      - "
    "chevron\",\"      - circular_disk\",\"      - cylinder\",\"      - sphere\",\""
    "      - round_corner_cube_prism\",\"Depending on 'shape', the following "
    "parameters must/may be specified:\",\"  - rectangle:\",\"      - length: "
    "length in meters\",\"      - width: width in meters\",\"  - "
    "checkerboard2x2:\",\"      - square_length: length of a square of the "
    "checkerboard in meters\",\"  - circular_disk:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"  - chevron:\",\"      - outside_edge_length: "
    "length of the two outer edges in meters\",\"      - thickness: thickness"
    " in meters\",\"  - cylinder:\",\"      - diameter: diameter in meters\",\""
    "      - height: height in meters\",\"  - sphere:\",\"      - diameter: "
    "diameter in meters\",\"  - round_corner_cube_prism:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"Optional parameters:\",\"    - description: string"
    " describing the object\",\"    - surface_type: surface material type "
    "(either 'retro_reflective_foil' or 'diffuse')\"],\"types\":[{\"shape\":\"rec"
    "tangle\",\"width\":0.3,\"name\":\"Rectangle "
    "60x30\",\"length\":0.6,\"description\":\"Rectangle (60cm x "
    "30cm)\"},{\"shape\":\"rectangle\",\"width\":0.4,\"name\":\"Rectangle "
    "80x40\",\"length\":0.8,\"description\":\"Rectangle (80cm x "
    "40cm)\"},{\"shape\":\"checkerboard2x2\",\"name\":\"Checkerboard2x2 "
    "30\",\"description\":\"Checkerboard (square length: 30cm)\",\"square_length\""
    ":0.3},{\"shape\":\"checkerboard2x2\",\"name\":\"Checkerboard2x2 "
    "50\",\"description\":\"Checkerboard (square length: 50cm)\",\"square_length\""
    ":0.5},{\"shape\":\"chevron\",\"outside_edge_length\":0.6096,\"name\":\"Chevron "
    "24''/4''\",\"thickness\":0.1016,\"description\":\"Chevron (a=24''; b=4'')\"},"
    "{\"surface_type\":\"diffuse\",\"shape\":\"circular_disk\",\"name\":\"Circular "
    "Disk 50\",\"diameter\":0.5,\"description\":\" Circular Disk (diameter: "
    "50cm)\"},{\"name\":\"RIEGL flat reflector 50 "
    "mm\",\"diameter\":0.05,\"description\":\"flat circular reflector from "
    "retro-reflective foil\",\"surface_type\":\"retro_reflective_foil\",\"shape\":"
    "\"circular_disk\",\"offset\":0.0},{\"name\":\"RIEGL flat reflector 100 "
    "mm\",\"diameter\":0.1,\"description\":\"flat circular reflector from "
    "retro-reflective foil\",\"surface_type\":\"retro_reflective_foil\",\"shape\":"
    "\"circular_disk\",\"offset\":0.0},{\"name\":\"RIEGL flat reflector 150 "
    "mm\",\"diameter\":0.15,\"description\":\"flat circular reflector from "
    "retro-reflective foil\",\"surface_type\":\"retro_reflective_foil\",\"shape\":"
    "\"circular_disk\",\"offset\":0.0},{\"height\":0.05,\"name\":\"RIEGL cylindrical"
    " reflector 50 mm\",\"description\":\"cylindrical reflector from "
    "retro-reflective foil\",\"surface_type\":\"retro_reflective_foil\",\"shape\":"
    "\"cylinder\",\"diameter\":0.05},{\"height\":0.1,\"name\":\"RIEGL cylindrical "
    "reflector 100 mm\",\"description\":\"cylindrical reflector from "
    "retro-reflective foil\",\"surface_type\":\"retro_reflective_foil\",\"shape\":"
    "\"cylinder\",\"diameter\":0.1},{\"shape\":\"sphere\",\"name\":\"Sphere 200 "
    "mm\",\"diameter\":0.2,\"description\":\"Sphere (diameter: 200 "
    "mm)\"},{\"shape\":\"round_corner_cube_prism\",\"offset\":0.0,\"name\":\"Corner "
    "Cube Prism 50 mm\",\"diameter\":0.05,\"description\":\"round corner cube "
    "prism\"}]}"
};

// Details about the control object reference file
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE = {
    /* name        */ "riegl.control_object_reference_file",
    /* title       */ "Control Object Reference file",
    /* description */ "Details about the control object reference file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"reference_file\":{\"required\":[\"file_uui"
    "d\",\"file_path\"],\"type\":\"object\",\"properties\":{\"file_path\":{\"type\":\"str"
    "ing\",\"description\":\"Path of the control object file relative to "
    "referring file\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"Control "
    "object file's Universally Unique Identifier (RFC "
    "4122)\"}},\"description\":\"Reference to a control object "
    "file\"}},\"description\":\"Details about the control object reference file"
    "\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Control"
    " Object Reference file\"}"
    ,
    /* example: */
    "{\"reference_file\":{\"file_path\":\"../../../10_CONTROL_OBJECTS/ControlPoi"
    "nts.cpx\",\"file_uuid\":\"810f5d57-eccf-49ed-b07a-0cdd109b4213\"}}"
};

// Detection probability as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_DETECTION_PROBABILITY = {
    /* name        */ "riegl.detection_probability",
    /* title       */ "Detection Probability",
    /* description */ "Detection probability as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"amplitude\",\"detection_probability\"],\"$schema\":\"http://js"
    "on-schema.org/draft-04/schema#\",\"description\":\"Detection probability "
    "as a function of amplitude\",\"type\":\"object\",\"properties\":{\"detection_p"
    "robability\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"D"
    "etection probability [0..1]\"},\"amplitude\":{\"type\":\"array\",\"items\":{\"ty"
    "pe\":\"number\"},\"description\":\"Amplitude [dB]\"}},\"title\":\"Detection "
    "Probability\"}"
    ,
    /* example: */
    "{\"detection_probability\":[0.0,0.5,0.8,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]"
    ",\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0]}"
};

// Details about the device used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICE = {
    /* name        */ "riegl.device",
    /* title       */ "Device Information",
    /* description */ "Details about the device used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"device_type\",\"serial_number\"],\"$schema\":\"http://json-sch"
    "ema.org/draft-04/schema#\",\"description\":\"Details about the device used"
    " to acquire the point cloud\",\"type\":\"object\",\"properties\":{\"device_typ"
    "e\":{\"type\":\"string\",\"description\":\"Device type identifier (e.g. "
    "VZ-400i)\"},\"channel_text\":{\"type\":\"string\",\"description\":\"Optional "
    "channel description (e.g. 'Green Channel' for multi-channel "
    "devices)\"},\"device_name\":{\"type\":\"string\",\"description\":\"Optional "
    "device name (e.g. 'Scanner 1' for multi-scanner "
    "systems)\"},\"serial_number\":{\"type\":\"string\",\"description\":\"Device "
    "serial number (e.g. "
    "S2221234)\"},\"device_build\":{\"type\":\"string\",\"description\":\"Device "
    "build variant\"},\"channel_number\":{\"type\":\"integer\",\"minimum\":0,\"descri"
    "ption\":\"Laser channel number (not defined or 0: single channel "
    "device)\",\"exclusiveMinimum\":false}},\"title\":\"Device Information\"}"
    ,
    /* example: */
    "{\"device_type\":\"VZ-400i\",\"channel_text\":\"\",\"device_name\":\"Scanner "
    "1\",\"serial_number\":\"S2221234\",\"device_build\":\"\",\"channel_number\":0}"
};

// Scanner device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY = {
    /* name        */ "riegl.device_geometry",
    /* title       */ "Device Geometry",
    /* description */ "Scanner device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"primary\"],\"$schema\":\"http://json-schema.org/draft-04/sch"
    "ema#\",\"description\":\"Scanner device geometry details\",\"type\":\"object\","
    "\"properties\":{\"secondary\":{\"required\":[\"ID\",\"content\"],\"type\":\"object\""
    ",\"properties\":{\"content\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"de"
    "scription\":\"Internal calibration values\"},\"ID\":{\"minItems\":2,\"type\":\"a"
    "rray\",\"items\":{\"type\":\"integer\"},\"description\":\"Structure "
    "identifier\",\"maxItems\":2}},\"description\":\"Additional device geometry "
    "structure (optional)\"},\"primary\":{\"required\":[\"ID\",\"content\"],\"type\":\""
    "object\",\"properties\":{\"content\":{\"type\":\"array\",\"items\":{\"type\":\"numbe"
    "r\"},\"description\":\"Internal calibration values\"},\"ID\":{\"minItems\":2,\"t"
    "ype\":\"array\",\"items\":{\"type\":\"integer\"},\"description\":\"Structure "
    "identifier\",\"maxItems\":2}},\"description\":\"Primary device geometry "
    "structure (mandatory)\"},\"amu\":{\"type\":\"object\",\"properties\":{\"frameCC\""
    ":{\"type\":\"number\",\"minimum\":0,\"description\":\"Frame Circle Count "
    "(number of LSBs per full rotation about frame axis)\",\"exclusiveMinimum"
    "\":false},\"lineCC\":{\"type\":\"number\",\"minimum\":0,\"description\":\"Line "
    "Circle Count (number of LSBs per full rotation about line "
    "axis)\",\"exclusiveMinimum\":false}},\"description\":\"Angle Measurement "
    "Unit\"}},\"title\":\"Device Geometry\"}"
    ,
    /* example: */
    "{\"secondary\":{\"content\":[0],\"ID\":[91,0]},\"primary\":{\"content\":[0],\"ID\""
    ":[4,0]},\"amu\":{\"frameCC\":124000,\"lineCC\":124000}}"
};

// Scanner passive channel device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL = {
    /* name        */ "riegl.device_geometry_passive_channel",
    /* title       */ "Device Geometry Passive Channel",
    /* description */ "Scanner passive channel device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"primary\"],\"$schema\":\"http://json-schema.org/draft-04/sch"
    "ema#\",\"description\":\"Scanner passive channel device geometry details\","
    "\"type\":\"object\",\"properties\":{\"primary\":{\"required\":[\"ID\",\"content\"],\""
    "type\":\"object\",\"properties\":{\"content\":{\"type\":\"array\",\"items\":{\"type\""
    ":\"number\"},\"description\":\"Internal calibration values\"},\"ID\":{\"minItem"
    "s\":2,\"type\":\"array\",\"items\":{\"type\":\"integer\"},\"description\":\"Structur"
    "e identifier\",\"maxItems\":2}},\"description\":\"Primary device geometry "
    "structure (mandatory)\"}},\"title\":\"Device Geometry Passive Channel\"}"
    ,
    /* example: */
    "{\"primary\":{\"content\":[0],\"ID\":[143,0]}}"
};

// Limits of the measured values output by the device
const MetaDataItemInfo RDB_RIEGL_DEVICE_OUTPUT_LIMITS = {
    /* name        */ "riegl.device_output_limits",
    /* title       */ "Device Output Limits",
    /* description */ "Limits of the measured values output by the device",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"amplitude_maximum\":{\"type\":\"number\",\"d"
    "escription\":\"Maximum possible amplitude in "
    "dB.\"},\"reflectance_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "possible reflectance in dB.\"},\"background_radiation_maximum\":{\"type\":\""
    "number\",\"description\":\"Maximum possible background radiation.\"},\"refle"
    "ctance_minimum\":{\"type\":\"number\",\"description\":\"Minimum possible "
    "reflectance in "
    "dB.\"},\"amplitude_minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "possible amplitude in "
    "dB.\"},\"echo_count_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "number of echoes a laser shot can have.\"},\"background_radiation_minimu"
    "m\":{\"type\":\"number\",\"description\":\"Minimum possible background radiati"
    "on.\"},\"deviation_minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "possible pulse shape deviation.\"},\"mta_zone_count_maximum\":{\"type\":\"nu"
    "mber\",\"description\":\"Maximum number of MTA "
    "zones.\"},\"deviation_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "possible pulse shape "
    "deviation.\"},\"range_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "possible range in "
    "meters.\"},\"range_minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "possible range in meters.\"}},\"description\":\"Limits of the measured "
    "values output by the device. The limits depend on the device type, "
    "measurement program and/or scan pattern.\",\"$schema\":\"http://json-schem"
    "a.org/draft-04/schema#\",\"title\":\"Device Output Limits\"}"
    ,
    /* example: */
    "{\"amplitude_maximum\":100.0,\"background_radiation_minimum\":0,\"reflectan"
    "ce_maximum\":100.0,\"deviation_minimum\":-1,\"mta_zone_count_maximum\":7,\"d"
    "eviation_maximum\":32767,\"background_radiation_maximum\":0,\"reflectance_"
    "minimum\":-100.0,\"amplitude_minimum\":0.0,\"range_maximum\":10000.0,\"range"
    "_minimum\":2.9}"
};

// Details about the devices used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICES = {
    /* name        */ "riegl.devices",
    /* title       */ "Devices Information",
    /* description */ "Details about the devices used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"array\",\"items\":{\"type\":\"object\",\"required\":[\"device_type\",\"se"
    "rial_number\"],\"properties\":{\"device_type\":{\"type\":\"string\",\"descriptio"
    "n\":\"Device type identifier (e.g. "
    "VZ-400i)\"},\"channel_text\":{\"type\":\"string\",\"description\":\"Optional "
    "channel description (e.g. 'Green Channel' for multi-channel "
    "devices)\"},\"device_name\":{\"type\":\"string\",\"description\":\"Optional "
    "device name (e.g. 'Scanner 1' for multi-scanner "
    "systems)\"},\"serial_number\":{\"type\":\"string\",\"description\":\"Device "
    "serial number (e.g. "
    "S2221234)\"},\"signed\":{\"type\":\"boolean\",\"description\":\"Flag that is set"
    " when the original 'riegl.device' entry in the source file was "
    "correctly "
    "signed.\"},\"device_build\":{\"type\":\"string\",\"description\":\"Device build "
    "variant\"},\"channel_number\":{\"type\":\"integer\",\"minimum\":0,\"description\""
    ":\"Laser channel number (not defined or 0: single channel "
    "device)\",\"exclusiveMinimum\":false}}},\"description\":\"Details about the "
    "devices used to acquire the point cloud (e.g. when merging point "
    "clouds of different devices)\",\"$schema\":\"http://json-schema.org/draft-"
    "04/schema#\",\"title\":\"Devices Information\"}"
    ,
    /* example: */
    "[{\"device_type\":\"VZ-400i\",\"channel_text\":\"\",\"device_name\":\"Scanner 1\","
    "\"serial_number\":\"S2221234\",\"signed\":false,\"device_build\":\"\",\"channel_n"
    "umber\":0},{\"device_type\":\"VQ-1560i-DW\",\"channel_text\":\"\",\"device_name\""
    ":\"Scanner 2\",\"serial_number\":\"S2222680\",\"signed\":true,\"device_build\":\""
    "\",\"channel_number\":1},{\"device_type\":\"VQ-1560i-DW\",\"channel_text\":\"\",\""
    "device_name\":\"Scanner 3\",\"serial_number\":\"S2222680\",\"signed\":true,\"dev"
    "ice_build\":\"\",\"channel_number\":2}]"
};

// Dyntrig
const MetaDataItemInfo RDB_RIEGL_DYNTRIG = {
    /* name        */ "riegl.dyntrig",
    /* title       */ "Dyntrig",
    /* description */ "Dyntrig",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"pre\":{\"required\":[\"nc\",\"a\"],\"type\":\"object\",\"propertie"
    "s\":{\"a\":{\"minItems\":1,\"type\":\"array\",\"items\":{\"type\":\"number\"},\"descri"
    "ption\":\"...\",\"maxItems\":2080},\"nc\":{\"maximum\":255,\"type\":\"integer\",\"mi"
    "nimum\":0,\"description\":\"Number of entries\"}},\"description\":\"Dyntrig "
    "pre values\"},\"scale\":{\"type\":\"number\",\"description\":\"Scale in units of"
    " dB, for calculation of line: line number N=(amplitude-offset)/scale\"}"
    ",\"post\":{\"required\":[\"nc\",\"a\"],\"type\":\"object\",\"properties\":{\"a\":{\"min"
    "Items\":1,\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"...\","
    "\"maxItems\":2080},\"nc\":{\"maximum\":255,\"type\":\"integer\",\"minimum\":0,\"des"
    "cription\":\"Number of entries\"}},\"description\":\"Dyntrig post values\"},\""
    "tab\":{\"minItems\":1,\"type\":\"array\",\"items\":{\"required\":[\"thra1\",\"del1\","
    "\"dec1\",\"thra2\",\"del2\",\"dec2\"],\"type\":\"object\",\"properties\":{\"thra2\":{\""
    "type\":\"number\",\"description\":\"Pre-trigger threshold in units of "
    "dB\"},\"del1\":{\"type\":\"number\",\"description\":\"Length of constant "
    "post-trigger threshold elevation in units of "
    "m\"},\"dec1\":{\"type\":\"number\",\"description\":\"Decay of post-trigger "
    "threshold after del1 in units of "
    "dB/m\"},\"del2\":{\"type\":\"number\",\"description\":\"Length of constant "
    "pre-trigger threshold elevation in units of "
    "m\"},\"thra1\":{\"type\":\"number\",\"description\":\"Post-trigger threshold in "
    "units of dB\"},\"dec2\":{\"type\":\"number\",\"description\":\"Rise of "
    "pre-trigger threshold after del2 in units of dB/m\"}},\"description\":\".."
    ".\"},\"description\":\"...\",\"maxItems\":128},\"offset\":{\"type\":\"number\",\"des"
    "cription\":\"Offset in units of dB, for calculation of line\"}},\"descript"
    "ion\":\"Dyntrig\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"ti"
    "tle\":\"Dyntrig\"}"
    ,
    /* example: */
    "{\"pre\":{\"a\":[78,86,126,134,31],\"nc\":128},\"scale\":1.0,\"post\":{\"a\":[78,8"
    "6,126,134,31],\"nc\":128},\"tab\":[{\"thra2\":0.0,\"del1\":0.0,\"dec1\":0.0,\"del"
    "2\":0.0,\"thra1\":0.0,\"dec2\":0.0}],\"offset\":0.0}"
};

// Details about echo files
const MetaDataItemInfo RDB_RIEGL_ECHO_INFO = {
    /* name        */ "riegl.echo_info",
    /* title       */ "Echo Information",
    /* description */ "Details about echo files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"echo_file\"],\"$schema\":\"http://json-schema.org/draft-04/s"
    "chema#\",\"description\":\"Details about echo files\",\"type\":\"object\",\"prop"
    "erties\":{\"echo_file\":{\"type\":\"object\",\"required\":[\"file_extension\"],\"p"
    "roperties\":{\"file_uuid\":{\"type\":\"string\",\"description\":\"File's "
    "Universally Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Echo file "
    "extension, without the leading dot\"}}}},\"title\":\"Echo Information\"}"
    ,
    /* example: */
    "{\"echo_file\":{\"file_uuid\":\"26a03615-67c0-4bea-8fe8-c577378fe661\",\"file"
    "_extension\":\"owp\"}}"
};

// Details for exponential decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_EXPONENTIAL_DECOMPOSITION = {
    /* name        */ "riegl.exponential_decomposition",
    /* title       */ "Exponential Decomposition",
    /* description */ "Details for exponential decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"additionalProperties\":false,\"description\":\"Details for exponential "
    "decomposition of full waveform data\",\"definitions\":{\"channel\":{\"type\":"
    "\"object\",\"required\":[\"delay\",\"scale\",\"parameter\"],\"properties\":{\"param"
    "eter\":{\"required\":[\"A\",\"B\",\"gamma\",\"omega\"],\"type\":\"object\",\"propertie"
    "s\":{\"gamma\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"d"
    "ecay in 1/second\"},\"omega\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\""
    "description\":\"angular frequency in "
    "Hz\"},\"A\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"real"
    " part of amplitude factor in units of full-scale\"},\"B\":{\"type\":\"array\""
    ",\"items\":{\"type\":\"number\"},\"description\":\"imaginary part of amplitude "
    "factor in units of full-scale\"}},\"description\":\"parameters of the "
    "syswave exponential "
    "sum\"},\"scale\":{\"type\":\"number\",\"description\":\"amplitude calibration\"},"
    "\"a_lin\":{\"minimum\":0,\"exclusiveMaximum\":false,\"description\":\"relative "
    "linear amplitude range [0..1]\",\"maximum\":1,\"type\":\"number\",\"exclusiveM"
    "inimum\":false},\"delay\":{\"type\":\"number\",\"description\":\"delay "
    "calibration in seconds\"}}}},\"type\":\"object\",\"patternProperties\":{\"^[0-"
    "9]+$\":{\"$ref\":\"#/definitions/channel\",\"description\":\"one field per "
    "channel, field name is channel index\"}},\"$schema\":\"http://json-schema."
    "org/draft-04/schema#\",\"title\":\"Exponential Decomposition\"}"
    ,
    /* example: */
    "{\"0\":{\"parameter\":{\"gamma\":[-1094726528.0,-769562752.0,-848000064.0],\""
    "omega\":[352020896.0,3647927552.0,-1977987072.0],\"A\":[0.977245092391967"
    "8,0.3354335129261017,-1.312678575515747],\"B\":[-3.9813032150268555,0.08"
    "622030913829803,-0.3152860999107361]},\"scale\":1.0,\"a_lin\":0.27,\"delay\""
    ":3.783458418887631e-09},\"1\":{\"parameter\":{\"gamma\":[-1094726528.0,-7695"
    "62752.0,-848000064.0],\"omega\":[352020896.0,3647927552.0,-1977987072.0]"
    ",\"A\":[0.9,0.3,-1.3],\"B\":[-3.9,0.0,-0.3]},\"scale\":1.0,\"a_lin\":0.9,\"dela"
    "y\":3.5e-09}}"
};

// Details for Gaussian decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_GAUSSIAN_DECOMPOSITION = {
    /* name        */ "riegl.gaussian_decomposition",
    /* title       */ "Gaussian Decomposition",
    /* description */ "Details for Gaussian decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"amplitude_lsb_low_power\",\"amplitude_lsb_high_power\",\"amp"
    "litude_db\",\"range_offset_sec_low_power\",\"range_offset_sec_high_power\"]"
    ",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"ri"
    "egl.gaussian_decomposition contains information relevant for "
    "extracting calibrated amplitudes and calibrated ranges from a Gaussian"
    " decomposition of full waveform data. This information is contained in"
    " a table with five columns. Two columns are to be used as input: "
    "amplitude_lsb_low_power and amplitude_lsb_high_power. The other three "
    "columns provide the outputs. Amplitude_db gives the calibrated "
    "amplitude in the optical regime in decibels. The range offset columns "
    "provide additive range offsets, given in units of seconds, for each ch"
    "annel.\",\"type\":\"object\",\"properties\":{\"range_offset_sec_high_power\":{\""
    "type\":\"array\",\"items\":{\"type\":\"number\"}},\"range_offset_sec_low_power\":"
    "{\"type\":\"array\",\"items\":{\"type\":\"number\"}},\"amplitude_lsb_high_power\":"
    "{\"type\":\"array\",\"items\":{\"type\":\"number\"}},\"amplitude_lsb_low_power\":{"
    "\"type\":\"array\",\"items\":{\"type\":\"number\"}},\"amplitude_db\":{\"type\":\"arra"
    "y\",\"items\":{\"type\":\"number\"}}},\"title\":\"Gaussian Decomposition\"}"
    ,
    /* example: */
    "{\"range_offset_sec_high_power\":[],\"range_offset_sec_low_power\":[],\"amp"
    "litude_lsb_high_power\":[],\"amplitude_lsb_low_power\":[],\"amplitude_db\":"
    "[]}"
};

// Point cloud georeferencing information
const MetaDataItemInfo RDB_RIEGL_GEO_TAG = {
    /* name        */ "riegl.geo_tag",
    /* title       */ "Geo Tag",
    /* description */ "Point cloud georeferencing information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"pose\":{\"minItems\":4,\"type\":\"array\",\"it"
    "ems\":{\"minItems\":4,\"type\":\"array\",\"items\":{\"type\":\"number\",\"descriptio"
    "n\":\"columns\"},\"description\":\"rows\",\"maxItems\":4},\"description\":\"Coordi"
    "nate Transformation Matrix to transform from File Coordinate System to"
    " Global Coordinate Reference System. 4x4 matrix stored as two "
    "dimensional array, row major order.\",\"maxItems\":4},\"crs\":{\"type\":\"obje"
    "ct\",\"properties\":{\"epsg\":{\"type\":\"integer\",\"minimum\":0,\"description\":\""
    "EPSG code\"},\"name\":{\"type\":\"string\",\"description\":\"Coordinate "
    "reference system "
    "name\"},\"wkt\":{\"type\":\"string\",\"description\":\"\\\"Well-Known Text\\\" "
    "string, OGC WKT dialect (see http://www.opengeospatial.org/standards/w"
    "kt-crs)\"}},\"description\":\"Global Coordinate Reference System. Please "
    "note that only 3D Cartesian Coordinate Systems are "
    "allowed.\"}},\"description\":\"Point cloud georeferencing information\",\"$s"
    "chema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Geo Tag\"}"
    ,
    /* example: */
    "{\"pose\":[[-0.269827776749716,-0.723017716139738,0.635954678449952,4063"
    "882.500831],[0.962908599449764,-0.20260517250352,0.178208229833847,113"
    "8787.607461],[0.0,0.660451759194338,0.7508684796801,4766084.550196],[0"
    ".0,0.0,0.0,1.0]],\"crs\":{\"epsg\":4978,\"name\":\"WGS84 "
    "Geocentric\",\"wkt\":\"GEOCCS[\\\"WGS84 Geocentric\\\",DATUM[\\\"WGS84\\\",SPHEROI"
    "D[\\\"WGS84\\\",6378137.000,298.257223563,AUTHORITY[\\\"EPSG\\\",\\\"7030\\\"]],AU"
    "THORITY[\\\"EPSG\\\",\\\"6326\\\"]],PRIMEM[\\\"Greenwich\\\",0.0000000000000000,AU"
    "THORITY[\\\"EPSG\\\",\\\"8901\\\"]],UNIT[\\\"Meter\\\",1.00000000000000000000,AUTH"
    "ORITY[\\\"EPSG\\\",\\\"9001\\\"]],AXIS[\\\"X\\\",OTHER],AXIS[\\\"Y\\\",EAST],AXIS[\\\"Z\\"
    "\",NORTH],AUTHORITY[\\\"EPSG\\\",\\\"4978\\\"]]\"}}"
};

// Geometric scale factor applied to point coordinates
const MetaDataItemInfo RDB_RIEGL_GEOMETRIC_SCALE_FACTOR = {
    /* name        */ "riegl.geometric_scale_factor",
    /* title       */ "Geometric Scale Factor",
    /* description */ "Geometric scale factor applied to point coordinates",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"minimum\":0,\"type\":\"number\",\"description\":\"Geometric scale factor "
    "applied to point coordinates\",\"$schema\":\"http://json-schema.org/draft-"
    "04/schema#\",\"exclusiveMinimum\":true}"
    ,
    /* example: */
    "1.0"
};

// Parameters used for georeferencing of the point cloud
const MetaDataItemInfo RDB_RIEGL_GEOREFERENCING_PARAMETERS = {
    /* name        */ "riegl.georeferencing_parameters",
    /* title       */ "Georeferencing Parameters",
    /* description */ "Parameters used for georeferencing of the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"trajectory_file\":{\"required\":[\"file_ex"
    "tension\"],\"type\":\"object\",\"properties\":{\"file_uuid\":{\"type\":\"string\",\""
    "description\":\"File's Universally Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Trajectory "
    "file extension, without the leading dot\"}},\"description\":\"Trajectory "
    "data used for georeferencing of the point cloud\"},\"socs_to_body_matrix"
    "\":{\"minItems\":4,\"type\":\"array\",\"items\":{\"minItems\":4,\"type\":\"array\",\"i"
    "tems\":{\"type\":\"number\",\"description\":\"columns\"},\"description\":\"rows\",\""
    "maxItems\":4},\"description\":\"Coordinate Transformation Matrix to "
    "transform from Scanner's Own Coordinate System to Body Coordinate "
    "System. 4x4 matrix stored as two dimensional array, row major order.\","
    "\"maxItems\":4},\"trajectory_offsets\":{\"type\":\"object\",\"properties\":{\"ver"
    "sion\":{\"type\":\"integer\",\"description\":\"Meaning of offset values and "
    "how to apply them; version 0: "
    "Rz(yaw+offset_yaw)*Ry(pitch+offset_pitch)*Rx(roll+offset_roll), "
    "version 1: Rz(yaw)*Ry(pitch)*Rx(roll) * Rz(offset_yaw)*Ry(offset_pitch"
    ")*Rx(offset_roll)\"},\"offset_time\":{\"type\":\"number\",\"description\":\"[s]\""
    "},\"offset_roll\":{\"type\":\"number\",\"description\":\"[deg]\"},\"offset_height"
    "\":{\"type\":\"number\",\"description\":\"[m]\"},\"offset_east\":{\"type\":\"number\""
    ",\"description\":\"[m]\"},\"offset_yaw\":{\"type\":\"number\",\"description\":\"[de"
    "g]\"},\"offset_north\":{\"type\":\"number\",\"description\":\"[m]\"},\"offset_pitc"
    "h\":{\"type\":\"number\",\"description\":\"[deg]\"}},\"description\":\"Correction "
    "offsets applied to the trajectory data\"},\"socs_to_rocs_matrix\":{\"minIt"
    "ems\":4,\"type\":\"array\",\"items\":{\"minItems\":4,\"type\":\"array\",\"items\":{\"t"
    "ype\":\"number\",\"description\":\"columns\"},\"description\":\"rows\",\"maxItems\""
    ":4},\"description\":\"Coordinate Transformation Matrix to transform from "
    "Scanner's Own Coordinate System to Record Coordinate System. 4x4 "
    "matrix stored as two dimensional array, row major order.\",\"maxItems\":4"
    "},\"body_coordinate_system_type\":{\"enum\":[\"NED\",\"ENU\"],\"type\":\"string\","
    "\"description\":\"BODY coordinate frame (NED: North-East-Down, ENU: "
    "East-North-Up), default: NED\"}},\"description\":\"Parameters used for "
    "georeferencing of the point cloud\",\"$schema\":\"http://json-schema.org/d"
    "raft-04/schema#\",\"title\":\"Georeferencing Parameters\"}"
    ,
    /* example: */
    "{\"trajectory_file\":{\"file_uuid\":\"93a03615-66c0-4bea-8ff8-c577378fe660\""
    ",\"file_extension\":\"pofx\"},\"socs_to_body_matrix\":[[-0.269827776749716,-"
    "0.723017716139738,0.635954678449952,0.0],[0.962908599449764,-0.2026051"
    "7250352,0.178208229833847,0.0],[0.0,0.660451759194338,0.7508684796801,"
    "0.0],[0.0,0.0,0.0,1.0]],\"trajectory_offsets\":{\"version\":0,\"offset_time"
    "\":18.007,\"offset_roll\":0.03,\"offset_height\":-0.2,\"offset_east\":0.15,\"o"
    "ffset_yaw\":-0.45,\"offset_north\":0.07,\"offset_pitch\":0.01},\"body_coordi"
    "nate_system_type\":\"NED\"}"
};

// Map of item names
const MetaDataItemInfo RDB_RIEGL_ITEM_NAMES = {
    /* name        */ "riegl.item_names",
    /* title       */ "Item Names",
    /* description */ "Map of item names",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"additionalProperties\":false,\"patternProperties\":{\"^-?[0-9]+$\":{\"type"
    "\":\"string\",\"description\":\"One field per item, field name is item id, "
    "field value is item name\"}},\"description\":\"Map of item names\",\"type\":\""
    "object\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"I"
    "tem Names\"}"
    ,
    /* example: */
    "{\"-1\":\"Name of item with id -1\",\"2\":\"Name of item with id 2\",\"1\":\"Name"
    " of item with id 1\",\"47\":\"Name of item with id 47\"}"
};

// License keys for software features
const MetaDataItemInfo RDB_RIEGL_LICENSES = {
    /* name        */ "riegl.licenses",
    /* title       */ "Software License Keys",
    /* description */ "License keys for software features",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"additionalProperties\":false,\"patternProperties\":{\"^.*$\":{\"minItems\":"
    "1,\"type\":\"array\",\"items\":{\"type\":\"string\",\"description\":\"License key "
    "(example: '46AE032A - 39882AC4 - 9EC0A184 - "
    "6F163D73')\"},\"description\":\"Each field of the object represents a "
    "feature and holds a list of license keys, where the field name is the "
    "feature name.\"}},\"description\":\"License keys for software features\",\"t"
    "ype\":\"object\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"tit"
    "le\":\"Software License Keys\"}"
    ,
    /* example: */
    "{\"MTA resolution\":[\"468E020A - 39A922E4 - B681A184 - 673E3D72\"],\"Full "
    "Waveform Analysis Topography\":[\"0FD5FF07 - 011A1255 - 9F76CACA - "
    "8D2ED557\"],\"Georeferencing\":[\"46AE032A - 39882AC4 - 9EC0A184 - "
    "6F163D73\"],\"Full Waveform Analysis Topography with GPU "
    "support\":[\"8AB44126 - 23B92250 - 16E2689F - 34EF7E7B\"]}"
};

// Parameters for MTA processing
const MetaDataItemInfo RDB_RIEGL_MTA_SETTINGS = {
    /* name        */ "riegl.mta_settings",
    /* title       */ "MTA Settings",
    /* description */ "Parameters for MTA processing",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"zone_width\":{\"type\":\"number\",\"minimum\""
    ":0,\"description\":\"Width of a MTA zone in meter.\"},\"modulation_depth\":{"
    "\"type\":\"number\",\"minimum\":0,\"description\":\"Depth of pulse position "
    "modulation in meter.\"},\"zone_count\":{\"maximum\":255,\"type\":\"integer\",\"m"
    "inimum\":0,\"description\":\"Maximum number of MTA "
    "zones.\"}},\"description\":\"Parameters for MTA processing\",\"$schema\":\"htt"
    "p://json-schema.org/draft-04/schema#\",\"title\":\"MTA Settings\"}"
    ,
    /* example: */
    "{\"zone_width\":149.896225,\"modulation_depth\":9.368514,\"zone_count\":23}"
};

// Lookup table for range correction based on raw range
const MetaDataItemInfo RDB_RIEGL_NEAR_RANGE_CORRECTION = {
    /* name        */ "riegl.near_range_correction",
    /* title       */ "Near Range Correction Table",
    /* description */ "Lookup table for range correction based on raw range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"delta\",\"content\"],\"$schema\":\"http://json-schema.org/draf"
    "t-04/schema#\",\"description\":\"Lookup table for range correction based "
    "on raw range\",\"type\":\"object\",\"properties\":{\"content\":{\"minItems\":1,\"t"
    "ype\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"Correction value"
    " [m] to be added to the raw "
    "range\",\"maxItems\":2000},\"delta\":{\"type\":\"number\",\"description\":\"Delta "
    "between table entries [m], first entry is at range = 0 "
    "m\"}},\"title\":\"Near Range Correction Table\"}"
    ,
    /* example: */
    "{\"content\":[0.0],\"delta\":0.512}"
};

// Standard deviation for range and amplitude as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_NOISE_ESTIMATES = {
    /* name        */ "riegl.noise_estimates",
    /* title       */ "Noise Estimates",
    /* description */ "Standard deviation for range and amplitude as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"amplitude\",\"range_sigma\",\"amplitude_sigma\"],\"$schema\":\"h"
    "ttp://json-schema.org/draft-04/schema#\",\"description\":\"Standard "
    "deviation for range and amplitude as a function of amplitude\",\"type\":\""
    "object\",\"properties\":{\"range_sigma\":{\"type\":\"array\",\"items\":{\"type\":\"n"
    "umber\"},\"description\":\"Sigma range [m]\"},\"amplitude\":{\"type\":\"array\",\""
    "items\":{\"type\":\"number\"},\"description\":\"Amplitude [dB]\"},\"amplitude_si"
    "gma\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"Sigma "
    "amplitude [dB]\"}},\"title\":\"Noise Estimates\"}"
    ,
    /* example: */
    "{\"range_sigma\":[0.065,0.056,0.046,0.038,0.032,0.027,0.024,0.021,0.018,"
    "0.016,0.014],\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0"
    "],\"amplitude_sigma\":[0.988,0.988,0.875,0.774,0.686,0.608,0.54,0.482,0."
    "432,0.39,0.354]}"
};

// Notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_NOTCH_FILTER = {
    /* name        */ "riegl.notch_filter",
    /* title       */ "Notch Filter",
    /* description */ "Notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"range_minimum\",\"range_maximum\",\"amplitude_maximum\"],\"$sc"
    "hema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"Notch "
    "filter parameters for window glass echoes\",\"type\":\"object\",\"properties"
    "\":{\"amplitude_maximum\":{\"type\":\"number\",\"minimum\":0,\"description\":\"Max"
    "imum amplitude "
    "[dB]\"},\"range_maximum\":{\"type\":\"number\",\"description\":\"Maximum range "
    "[m]\"},\"range_minimum\":{\"type\":\"number\",\"description\":\"Minimum range "
    "[m]\"}},\"title\":\"Notch Filter\"}"
    ,
    /* example: */
    "{\"amplitude_maximum\":18.0,\"range_maximum\":0.2,\"range_minimum\":-0.5}"
};

// Details about the pixels contained in the file
const MetaDataItemInfo RDB_RIEGL_PIXEL_INFO = {
    /* name        */ "riegl.pixel_info",
    /* title       */ "Pixel Information",
    /* description */ "Details about the pixels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"size\"],\"description\":\"Details about the pixels contained"
    " in the file\",\"definitions\":{\"pixel_size\":{\"minItems\":2,\"type\":\"array\""
    ",\"items\":{\"type\":\"number\",\"minimum\":0,\"description\":\"Length of pixel "
    "edge [m].\"},\"description\":\"Size of pixels.\",\"maxItems\":2}},\"type\":\"obj"
    "ect\",\"properties\":{\"size_llcs\":{\"$ref\":\"#/definitions/pixel_size\",\"des"
    "cription\":\"Size of pixels in a locally levelled cartesian coordinate "
    "system (xy). This is only used for pixels based on a map projection.\"}"
    ",\"size\":{\"$ref\":\"#/definitions/pixel_size\",\"description\":\"Size of "
    "pixels in file coordinate system.\"}},\"$schema\":\"http://json-schema.org"
    "/draft-04/schema#\",\"title\":\"Pixel Information\"}"
    ,
    /* example: */
    "{\"size_llcs\":[0.5156575252891171,0.5130835356683303],\"size\":[0.5971642"
    "834779395,0.5971642834779395]}"
};

// Details about the plane patch matching process
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_MATCHING = {
    /* name        */ "riegl.plane_patch_matching",
    /* title       */ "Plane Patch Matching",
    /* description */ "Details about the plane patch matching process",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"plane_patch_file_one\",\"plane_patch_file_two\"],\"descripti"
    "on\":\"Details about the plane patch matching process\",\"definitions\":{\"f"
    "ile_reference\":{\"required\":[\"file_uuid\",\"file_path\"],\"type\":\"object\",\""
    "properties\":{\"file_path\":{\"type\":\"string\",\"description\":\"Path of the "
    "plane patch file relative to the match "
    "file\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"Plane patch file's "
    "Universally Unique Identifier (RFC 4122)\"}},\"description\":\"Reference "
    "to a plane patch file\"}},\"type\":\"object\",\"properties\":{\"plane_patch_fi"
    "le_two\":{\"$ref\":\"#/definitions/file_reference\",\"description\":\"Referenc"
    "e to the plane patch file two\"},\"plane_patch_file_one\":{\"$ref\":\"#/defi"
    "nitions/file_reference\",\"description\":\"Reference to the plane patch "
    "file one\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title"
    "\":\"Plane Patch Matching\"}"
    ,
    /* example: */
    "{\"plane_patch_file_two\":{\"file_path\":\"project.ptch\",\"file_uuid\":\"fa47d"
    "509-a64e-49ce-8b14-ff3130fbefa9\"},\"plane_patch_file_one\":{\"file_path\":"
    "\"Record009_Line001/191025_121410_Scanner_1.ptch\",\"file_uuid\":\"810f5d57"
    "-eccf-49ed-b07a-0cdd109b4213\"}}"
};

// Statistics about plane patches found by plane patch extractor
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_STATISTICS = {
    /* name        */ "riegl.plane_patch_statistics",
    /* title       */ "Plane Patch Statistics",
    /* description */ "Statistics about plane patches found by plane patch extractor",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"total_area\":{\"type\":\"number\",\"descript"
    "ion\":\"sum of all plane patch areas [m\\u00b2]\"},\"total_horizontal_area\""
    ":{\"type\":\"number\",\"description\":\"sum of all plane patch areas "
    "projected to horizontal plane [m\\u00b2]\"}},\"description\":\"Statistics "
    "about plane patches found by plane patch extractor\",\"$schema\":\"http://"
    "json-schema.org/draft-04/schema#\",\"title\":\"Plane Patch Statistics\"}"
    ,
    /* example: */
    "{\"total_area\":14007.965,\"total_horizontal_area\":13954.601}"
};

// Settings and classes for plane slope classification
const MetaDataItemInfo RDB_RIEGL_PLANE_SLOPE_CLASS_INFO = {
    /* name        */ "riegl.plane_slope_class_info",
    /* title       */ "Plane Slope Class Info",
    /* description */ "Settings and classes for plane slope classification",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"settings\",\"classes\"],\"description\":\"Settings and classes"
    " for plane slope classification\",\"definitions\":{\"method-1\":{\"required\""
    ":[\"plane_classification_method\",\"maximum_inclination_angle_horizontal\""
    "],\"type\":\"object\",\"properties\":{\"maximum_inclination_angle_horizontal\""
    ":{\"maximum\":360.0,\"type\":\"number\",\"minimum\":-360.0,\"description\":\"maxi"
    "mum inclination angle of horizontal plane patches [deg]\"},\"plane_class"
    "ification_method\":{\"maximum\":1,\"type\":\"integer\",\"minimum\":1,\"descripti"
    "on\":\"method ID (=1)\"}},\"description\":\"Classification method 1\"},\"metho"
    "d-2\":{\"required\":[\"plane_classification_method\",\"sloping_plane_classes"
    "_minimum_angle\",\"sloping_plane_classes_maximum_angle\"],\"type\":\"object\""
    ",\"properties\":{\"sloping_plane_classes_minimum_angle\":{\"maximum\":360.0,"
    "\"type\":\"number\",\"minimum\":-360.0,\"description\":\"minimum inclination "
    "angle of sloping plane patches [deg]\"},\"plane_classification_method\":{"
    "\"maximum\":2,\"type\":\"integer\",\"minimum\":2,\"description\":\"method ID (=2)"
    "\"},\"sloping_plane_classes_maximum_angle\":{\"maximum\":360.0,\"type\":\"numb"
    "er\",\"minimum\":-360.0,\"description\":\"maximum inclination angle of "
    "sloping plane patches [deg]\"}},\"description\":\"Classification method 2\""
    "}},\"type\":\"object\",\"properties\":{\"classes\":{\"additionalProperties\":fal"
    "se,\"type\":\"object\",\"patternProperties\":{\"^[0-9]+$\":{\"type\":\"string\",\"d"
    "escription\":\"one field per class, field name is class number, field "
    "value is class name\"}},\"description\":\"Class definition table\"},\"settin"
    "gs\":{\"type\":\"object\",\"oneOf\":[{\"$ref\":\"#/definitions/method-1\"},{\"$ref"
    "\":\"#/definitions/method-2\"}],\"description\":\"Classification settings, "
    "details see documentation of rdbplanes\"}},\"$schema\":\"http://json-schem"
    "a.org/draft-04/schema#\",\"title\":\"Plane Slope Class Info\"}"
    ,
    /* example: */
    "{\"classes\":{\"9\":\"vertical, pointing west\",\"3\":\"sloping, pointing up "
    "and south\",\"12\":\"sloping, pointing down and north\",\"11\":\"sloping, "
    "pointing down and south\",\"10\":\"sloping, pointing down and "
    "east\",\"2\":\"sloping, pointing up and east\",\"1\":\"horizontal, pointing "
    "up\",\"6\":\"vertical, pointing east\",\"4\":\"sloping, pointing up and "
    "north\",\"14\":\"horizontal, pointing down\",\"7\":\"vertical, pointing "
    "south\",\"5\":\"sloping, pointing up and west\",\"8\":\"vertical, pointing "
    "north\",\"13\":\"sloping, pointing down and west\"},\"settings\":{\"sloping_pl"
    "ane_classes_minimum_angle\":10.0,\"plane_classification_method\":2,\"slopi"
    "ng_plane_classes_maximum_angle\":70.0}}"
};

// Grouping and sorting of point attributes for visualization purposes
const MetaDataItemInfo RDB_RIEGL_POINT_ATTRIBUTE_GROUPS = {
    /* name        */ "riegl.point_attribute_groups",
    /* title       */ "Point Attribute Groups",
    /* description */ "Grouping and sorting of point attributes for visualization purposes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"additionalProperties\":false,\"patternProperties\":{\"^.*$\":{\"minItems\":"
    "1,\"type\":\"array\",\"items\":{\"type\":\"string\",\"description\":\"Point "
    "attribute full name or name pattern (perl regular expression "
    "syntax)\"},\"description\":\"Each field of the object represents a point "
    "attribute group and holds a list of point attributes, where the field "
    "name is the group name.\"}},\"description\":\"Grouping and sorting of "
    "point attributes for visualization purposes\",\"type\":\"object\",\"$schema\""
    ":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Point Attribute "
    "Groups\"}"
    ,
    /* example: */
    "{\"Other Attributes\":[\"riegl.selected\",\"riegl.visible\"],\"Time\":[\"riegl."
    "timestamp\"],\"Secondary "
    "Attributes\":[\"riegl.mirror_facet\",\"riegl.waveform_available\"],\"Primary"
    " Attributes\":[\"riegl.reflectance\",\"riegl.amplitude\",\"riegl.deviation\"]"
    ",\"Coordinates/Vectors\":[\"riegl.xyz\",\"riegl.range\",\"riegl.theta\",\"riegl"
    ".phi\"]}"
};

// Details about point cloud files
const MetaDataItemInfo RDB_RIEGL_POINTCLOUD_INFO = {
    /* name        */ "riegl.pointcloud_info",
    /* title       */ "Point Cloud Information",
    /* description */ "Details about point cloud files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"comments\":{\"type\":\"string\",\"descriptio"
    "n\":\"Comments\"},\"field_of_application\":{\"enum\":[\"unknown\",\"SLS\",\"TLS\",\""
    "KLS\",\"MLS\",\"ULS\",\"ALS\",\"BLS\",\"ILS\"],\"type\":\"string\",\"description\":\"Fie"
    "ld of application\"},\"project\":{\"type\":\"string\",\"description\":\"Project "
    "name\"}},\"description\":\"Details about point cloud files\",\"$schema\":\"htt"
    "p://json-schema.org/draft-04/schema#\",\"title\":\"Point Cloud "
    "Information\"}"
    ,
    /* example: */
    "{\"comments\":\"Line 3\",\"field_of_application\":\"ALS\",\"project\":\"Campaign "
    "4\"}"
};

// Estimated position and orientation information
const MetaDataItemInfo RDB_RIEGL_POSE_ESTIMATION = {
    /* name        */ "riegl.pose_estimation",
    /* title       */ "Pose Estimation",
    /* description */ "Estimated position and orientation information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"orientation\"],\"$schema\":\"http://json-schema.org/draft-04"
    "/schema#\",\"description\":\"Estimated position and orientation "
    "information as measured by GNSS, IMU or inclination sensors\",\"type\":\"o"
    "bject\",\"properties\":{\"orientation\":{\"required\":[\"roll\",\"pitch\",\"yaw\",\""
    "roll_accuracy\",\"pitch_accuracy\",\"yaw_accuracy\"],\"type\":\"object\",\"prope"
    "rties\":{\"roll_accuracy\":{\"type\":\"number\",\"minimum\":0,\"description\":\"Ro"
    "ll angle accuracy [deg]\",\"exclusiveMinimum\":true},\"yaw_accuracy\":{\"typ"
    "e\":\"number\",\"minimum\":0,\"description\":\"Yaw angle accuracy [deg]\",\"excl"
    "usiveMinimum\":true},\"pitch_accuracy\":{\"type\":\"number\",\"minimum\":0,\"des"
    "cription\":\"Pitch angle accuracy [deg]\",\"exclusiveMinimum\":true},\"roll\""
    ":{\"maximum\":360,\"type\":\"number\",\"minimum\":-360,\"description\":\"Roll "
    "angle about scanner X-axis [deg]\"},\"pitch\":{\"maximum\":360,\"type\":\"numb"
    "er\",\"minimum\":-360,\"description\":\"Pitch angle about scanner Y-axis [de"
    "g]\"},\"yaw\":{\"maximum\":360,\"type\":\"number\",\"minimum\":-360,\"description\""
    ":\"Yaw angle about scanner Z-axis [deg]\"}},\"description\":\"Orientation "
    "values and orientation accuracies, measured with IMU or inclination se"
    "nsors.\"},\"barometric_height_amsl\":{\"type\":\"number\",\"description\":\"Alti"
    "tude determined based on the atmospheric pressure according to the "
    "standard atmosphere laws [m].\"},\"position\":{\"required\":[\"coordinate_1\""
    ",\"coordinate_2\",\"coordinate_3\",\"horizontal_accuracy\",\"vertical_accurac"
    "y\",\"crs\"],\"type\":\"object\",\"properties\":{\"crs\":{\"required\":[\"epsg\"],\"ty"
    "pe\":\"object\",\"properties\":{\"epsg\":{\"type\":\"integer\",\"minimum\":0,\"descr"
    "iption\":\"EPSG "
    "code\"},\"wkt\":{\"type\":\"string\",\"description\":\"\\\"Well-Known Text\\\" "
    "string, OGC WKT dialect (see http://www.opengeospatial.org/standards/w"
    "kt-crs)\"}},\"description\":\"Global Coordinate Reference "
    "System\"},\"coordinate_1\":{\"type\":\"number\",\"description\":\"Coordinate 1 "
    "as defined by axis 1 of the specified CRS (e.g., X, "
    "Latitude)\"},\"coordinate_3\":{\"type\":\"number\",\"description\":\"Coordinate "
    "3 as defined by axis 3 of the specified CRS (e.g., Z, Altitude)\"},\"hor"
    "izontal_accuracy\":{\"type\":\"number\",\"minimum\":0,\"description\":\"Horizont"
    "al accuracy [m]\",\"exclusiveMinimum\":true},\"vertical_accuracy\":{\"type\":"
    "\"number\",\"minimum\":0,\"description\":\"Vertical accuracy [m]\",\"exclusiveM"
    "inimum\":true},\"coordinate_2\":{\"type\":\"number\",\"description\":\"Coordinat"
    "e 2 as defined by axis 2 of the specified CRS (e.g., Y, "
    "Longitude)\"}},\"description\":\"Position coordinates and position "
    "accuracy values as measured by GNSS in the specified Coordinate "
    "Reference System (CRS)\"}},\"title\":\"Pose Estimation\"}"
    ,
    /* example: */
    "{\"orientation\":{\"roll_accuracy\":0.009433783936875745,\"yaw_accuracy\":1."
    "0094337839368757,\"pitch_accuracy\":0.009433783936875745,\"roll\":3.147430"
    "73066123,\"pitch\":1.509153024827064,\"yaw\":101.87293630292045},\"barometr"
    "ic_height_amsl\":386.7457796227932,\"position\":{\"crs\":{\"epsg\":4979,\"wkt\""
    ":\"GEOGCS[\\\"WGS84 / Geographic\\\",DATUM[\\\"WGS84\\\",SPHEROID[\\\"WGS84\\\",637"
    "8137.000,298.257223563,AUTHORITY[\\\"EPSG\\\",\\\"7030\\\"]],AUTHORITY[\\\"EPSG\\"
    "\",\\\"6326\\\"]],PRIMEM[\\\"Greenwich\\\",0.0000000000000000,AUTHORITY[\\\"EPSG\\"
    "\",\\\"8901\\\"]],UNIT[\\\"Degree\\\",0.01745329251994329547,AUTHORITY[\\\"EPSG\\\""
    ",\\\"9102\\\"]],AXIS[\\\"Latitude\\\",NORTH],AXIS[\\\"Longitude\\\",EAST],AUTHORIT"
    "Y[\\\"EPSG\\\",\\\"4979\\\"]]\"},\"coordinate_1\":48.655799473,\"coordinate_3\":362"
    ".7124938964844,\"horizontal_accuracy\":0.810699999332428,\"vertical_accur"
    "acy\":1.3314999341964722,\"coordinate_2\":15.645033406}}"
};

// Details on position and orientation sensors
const MetaDataItemInfo RDB_RIEGL_POSE_SENSORS = {
    /* name        */ "riegl.pose_sensors",
    /* title       */ "Pose Sensors",
    /* description */ "Details on position and orientation sensors",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"gyroscope\",\"accelerometer\",\"magnetic_field_sensor\"],\"des"
    "cription\":\"Details on position and orientation sensors\",\"definitions\":"
    "{\"vector\":{\"minItems\":3,\"type\":\"array\",\"items\":{\"type\":\"number\",\"descr"
    "iption\":\"Index 0=X, 1=Y, 2=Z component\"},\"maxItems\":3}},\"type\":\"object"
    "\",\"properties\":{\"magnetic_field_sensor\":{\"required\":[\"unit\",\"x_axis\",\""
    "y_axis\",\"z_axis\",\"offset\",\"fixed\",\"relative_nonlinearity\"],\"type\":\"obj"
    "ect\",\"properties\":{\"y_axis\":{\"$ref\":\"#/definitions/vector\",\"descriptio"
    "n\":\"Sensitive Y axis of sensor at frame angle = "
    "0\"},\"z_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive Z"
    " axis of sensor at frame angle = "
    "0\"},\"x_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive X"
    " axis of sensor at frame angle = 0\"},\"relative_nonlinearity\":{\"$ref\":\""
    "#/definitions/vector\",\"description\":\"Relative nonlinearity, dimensionl"
    "ess\"},\"fixed\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Distortion"
    " of magnetic field caused by non-rotating scanner "
    "part\"},\"offset\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Value to"
    " be subtracted from raw measurement "
    "values\"},\"unit\":{\"type\":\"number\",\"minimum\":0,\"description\":\"Unit of "
    "raw data and calibration values, 1 LSB in "
    "nT\",\"exclusiveMinimum\":true}},\"description\":\"Magnetic Field Sensor det"
    "ails\"},\"gyroscope\":{\"required\":[\"unit\",\"x_axis\",\"y_axis\",\"z_axis\",\"off"
    "set\",\"origin\",\"relative_nonlinearity\"],\"type\":\"object\",\"properties\":{\""
    "y_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive Y axis"
    " of sensor at frame angle = "
    "0\"},\"z_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive Z"
    " axis of sensor at frame angle = "
    "0\"},\"x_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive X"
    " axis of sensor at frame angle = 0\"},\"relative_nonlinearity\":{\"$ref\":\""
    "#/definitions/vector\",\"description\":\"Relative nonlinearity, dimensionl"
    "ess\"},\"origin\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensor "
    "origin in SOCS [m] at frame angle = "
    "0\"},\"offset\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Value to be"
    " subtracted from raw measurement "
    "values\"},\"unit\":{\"type\":\"number\",\"minimum\":0,\"description\":\"Unit of "
    "raw data and calibration values, 1 LSB in "
    "rad/s\",\"exclusiveMinimum\":true}},\"description\":\"Gyroscope details\"},\"a"
    "ccelerometer\":{\"required\":[\"unit\",\"x_axis\",\"y_axis\",\"z_axis\",\"offset\","
    "\"origin\",\"relative_nonlinearity\"],\"type\":\"object\",\"properties\":{\"y_axi"
    "s\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive Y axis of "
    "sensor at frame angle = "
    "0\"},\"z_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive Z"
    " axis of sensor at frame angle = "
    "0\"},\"x_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive X"
    " axis of sensor at frame angle = 0\"},\"relative_nonlinearity\":{\"$ref\":\""
    "#/definitions/vector\",\"description\":\"Relative nonlinearity, dimensionl"
    "ess\"},\"origin\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensor "
    "origin in SOCS [m] at frame angle = "
    "0\"},\"offset\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Value to be"
    " subtracted from raw measurement "
    "values\"},\"unit\":{\"type\":\"number\",\"minimum\":0,\"description\":\"Unit of "
    "raw data and calibration values, 1 LSB in 9.81 "
    "m/s\\u00b2\",\"exclusiveMinimum\":true}},\"description\":\"Accelerometer deta"
    "ils\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Po"
    "se Sensors\"}"
    ,
    /* example: */
    "{\"magnetic_field_sensor\":{\"y_axis\":[0.00027888521435670555,-0.01142742"
    "4848079681,-5.204829722060822e-05],\"z_axis\":[0.00041987866279669106,7."
    "876977906562388e-05,0.011407104320824146],\"x_axis\":[-0.011162743903696"
    "537,-2.315962774446234e-05,0.00016818844596855342],\"relative_nonlinear"
    "ity\":[0.0,0.0,0.0],\"fixed\":[-1576.010498046875,1596.081787109375,0.0],"
    "\"offset\":[-23812.052734375,5606.57666015625,2493.28125],\"unit\":91.7431"
    "1828613281},\"gyroscope\":{\"y_axis\":[-0.440765917301178,-0.7897399663925"
    "171,119.5894775390625],\"z_axis\":[0.555869996547699,119.22135162353516,"
    "0.467585027217865],\"x_axis\":[-121.195556640625,0.8219714164733887,0.23"
    "13031703233719],\"relative_nonlinearity\":[2.888176311444113e-07,1.06274"
    "164579645e-07,-1.7186295080634935e-39],\"origin\":[0.026900000870227814,"
    "-0.03999999910593033,-0.08950000256299973],\"offset\":[-50.9260978698730"
    "5,146.15643310546875,62.4327278137207],\"unit\":0.00014544410805683583},"
    "\"accelerometer\":{\"y_axis\":[-7.027288913726807,-44.12333679199219,14952"
    ".3701171875],\"z_axis\":[1.639882206916809,15166.744140625,-116.99742889"
    "404297],\"x_axis\":[-15008.123046875,56.956390380859375,-60.517566680908"
    "2],\"relative_nonlinearity\":[0.0,0.0,0.0],\"origin\":[0.02690000087022781"
    "4,-0.03999999910593033,-0.08950000256299973],\"offset\":[-733.3636474609"
    "375,58.969032287597656,1060.2550048828125],\"unit\":6.666666740784422e-0"
    "5}}"
};

// Laser pulse position modulation used for MTA resolution
const MetaDataItemInfo RDB_RIEGL_PULSE_POSITION_MODULATION = {
    /* name        */ "riegl.pulse_position_modulation",
    /* title       */ "Pulse Position Modulation",
    /* description */ "Laser pulse position modulation used for MTA resolution",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"length\",\"num_mod_ampl\",\"pulse_interval\"],\"$schema\":\"http"
    "://json-schema.org/draft-04/schema#\",\"description\":\"Laser pulse "
    "position modulation used for MTA resolution\",\"type\":\"object\",\"properti"
    "es\":{\"pulse_interval\":{\"type\":\"array\",\"items\":{\"type\":\"number\",\"minimu"
    "m\":0},\"description\":\"Explicit table of the pulse position modulation "
    "used for MTA resolution. Table gives times between successive laser "
    "pulses in seconds.\"},\"phase_step\":{\"maximum\":255,\"type\":\"integer\",\"min"
    "imum\":0,\"description\":\"Step width in phase of modulation code from "
    "line to line\"},\"code_phase_mode\":{\"maximum\":255,\"type\":\"integer\",\"mini"
    "mum\":0,\"description\":\"0: no synchronization, 1: toggle between 2 "
    "phases, 2: increment with phase_increment\"},\"num_mod_ampl\":{\"maximum\":"
    "255,\"type\":\"integer\",\"minimum\":0,\"description\":\"Number of different "
    "modulation amplitudes (2: binary modulation)\"},\"length\":{\"maximum\":255"
    ",\"type\":\"integer\",\"minimum\":0,\"description\":\"Length of "
    "code\"}},\"title\":\"Pulse Position Modulation\"}"
    ,
    /* example: */
    "{\"pulse_interval\":[2.759375e-06,2.759375e-06,2.759375e-06,2.759375e-06"
    ",2.821875e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.82"
    "1875e-06,2.821875e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.821875e"
    "-06,2.821875e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.759375e-06,2"
    ".759375e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.821875e-06,2.8218"
    "75e-06,2.821875e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.821875e-0"
    "6],\"phase_step\":5,\"code_phase_mode\":2,\"num_mod_ampl\":2,\"length\":31}"
};

// Statistics about target distance wrt. SOCS origin
const MetaDataItemInfo RDB_RIEGL_RANGE_STATISTICS = {
    /* name        */ "riegl.range_statistics",
    /* title       */ "Range Statistics",
    /* description */ "Statistics about target distance wrt. SOCS origin",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"minimum\",\"average\",\"maximum\",\"std_dev\"],\"$schema\":\"http:"
    "//json-schema.org/draft-04/schema#\",\"description\":\"Statistics about "
    "target distance wrt. SOCS origin\",\"type\":\"object\",\"properties\":{\"maxim"
    "um\":{\"type\":\"number\",\"description\":\"Maximum "
    "value\"},\"minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "value\"},\"std_dev\":{\"type\":\"number\",\"description\":\"Standard "
    "deviation\"},\"average\":{\"type\":\"number\",\"description\":\"Average "
    "value\"}},\"title\":\"Range Statistics\"}"
    ,
    /* example: */
    "{\"maximum\":574.35,\"minimum\":0.919,\"std_dev\":24.349,\"average\":15.49738}"
};

// Receiver Internals
const MetaDataItemInfo RDB_RIEGL_RECEIVER_INTERNALS = {
    /* name        */ "riegl.receiver_internals",
    /* title       */ "Receiver Internals",
    /* description */ "Receiver Internals",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Receiver Internals\",\"definitions\":{\"fp\":{\"required\":[\""
    "s\",\"w\"],\"type\":\"object\",\"properties\":{\"s\":{\"minItems\":1,\"type\":\"array\""
    ",\"items\":{\"minItems\":1,\"type\":\"array\",\"items\":{\"type\":\"number\"},\"maxIt"
    "ems\":4096},\"maxItems\":256},\"w\":{\"minItems\":1,\"type\":\"array\",\"items\":{\""
    "minItems\":5,\"type\":\"array\",\"items\":{\"type\":\"number\"},\"maxItems\":5},\"ma"
    "xItems\":256}},\"description\":\"Fingerprint "
    "values\"},\"fp_table\":{\"desription\":\"scanner internal data\",\"type\":\"obje"
    "ct\",\"required\":[\"ch\",\"tc\",\"nx\",\"ny\",\"tv\"],\"properties\":{\"ch\":{\"type\":\""
    "integer\",\"max\":255,\"description\":\"channel number\",\"min\":0},\"nx\":{\"type"
    "\":\"integer\",\"max\":2048,\"description\":\"number of x entries\",\"min\":1},\"t"
    "c\":{\"type\":\"integer\",\"max\":255,\"description\":\"table data type code\",\"m"
    "in\":0},\"tv\":{\"minItems\":1,\"type\":\"array\",\"items\":{\"oneOf\":[{\"$ref\":\"#/"
    "definitions/fp_table_row\"},{\"type\":\"number\"}]},\"maxItems\":2048},\"ny\":{"
    "\"type\":\"integer\",\"max\":2048,\"description\":\"number of y entries\",\"min\":"
    "1}}},\"fp_table_row\":{\"minItems\":1,\"type\":\"array\",\"items\":{\"type\":\"numb"
    "er\"},\"maxItems\":2048}},\"type\":\"object\",\"properties\":{\"a\":{\"minItems\":1"
    ",\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"Amplitude [dB"
    "]\",\"maxItems\":256},\"t\":{\"additionalProperties\":false,\"type\":\"object\",\""
    "patternProperties\":{\"^[0-9]+$\":{\"$ref\":\"#/definitions/fp\",\"description"
    "\":\"one field per channel, field name is channel "
    "index\"}}},\"sr\":{\"type\":\"number\",\"minimum\":0,\"description\":\"Sample rate"
    " [Hz]\",\"exclusiveMinimum\":true},\"ns\":{\"maximum\":4095,\"type\":\"integer\","
    "\"minimum\":0,\"description\":\"Number of "
    "samples\"},\"ex\":{\"type\":\"object\",\"description\":\"DEPRECATED, use "
    "'riegl.exponential_decomposition' instead\"},\"mw\":{\"maximum\":4095,\"type"
    "\":\"number\",\"minimum\":0,\"description\":\"Maximum weight\",\"exclusiveMinimu"
    "m\":true},\"nt\":{\"maximum\":255,\"type\":\"integer\",\"minimum\":0,\"description"
    "\":\"Number of traces\"},\"si\":{\"maximum\":255,\"type\":\"number\",\"minimum\":0,"
    "\"description\":\"Start index (hw_start)\"},\"tbl\":{\"minItems\":1,\"type\":\"ar"
    "ray\",\"items\":{\"$ref\":\"#/definitions/fp_table\"},\"description\":\"various "
    "internal data\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\""
    "title\":\"Receiver Internals\"}"
    ,
    /* example: */
    "{\"a\":[-1.55],\"t\":{\"0\":{\"s\":[[1.23,4.56],[7.89,0.12]],\"w\":[[78,86,126,1"
    "34,31],[78,86,126,134,31]]},\"1\":{\"s\":[[1.23,4.56],[7.89,0.12]],\"w\":[[7"
    "8,86,126,134,31],[78,86,126,134,31]]}},\"sr\":7959997000.0,\"ns\":400,\"mw\""
    ":31,\"nt\":128,\"si\":48,\"tbl\":[{\"ch\":0,\"nx\":5,\"tc\":1,\"tv\":[[1,2,3,4,5],[1"
    ".1,2.2,3.3,4.4,5.5]],\"ny\":2}]}"
};

// Lookup table for reflectance calculation based on amplitude and range
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CALCULATION = {
    /* name        */ "riegl.reflectance_calculation",
    /* title       */ "Reflectance Calculation Table",
    /* description */ "Lookup table for reflectance calculation based on amplitude and range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"delta\",\"content\"],\"$schema\":\"http://json-schema.org/draf"
    "t-04/schema#\",\"description\":\"Lookup table for reflectance calculation "
    "based on amplitude and range\",\"type\":\"object\",\"properties\":{\"content\":"
    "{\"minItems\":1,\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\""
    "Correction value [dB] to be added to the amplitude\",\"maxItems\":2000},\""
    "delta\":{\"type\":\"number\",\"description\":\"Delta between table entries "
    "[m], first entry is at range = 0 m\"}},\"title\":\"Reflectance Calculation"
    " Table\"}"
    ,
    /* example: */
    "{\"content\":[-33.01],\"delta\":0.150918}"
};

// Range-dependent and scan-angle-dependent correction of reflectance reading
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CORRECTION = {
    /* name        */ "riegl.reflectance_correction",
    /* title       */ "Near-Range Reflectance Correction",
    /* description */ "Range-dependent and scan-angle-dependent correction of reflectance reading",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"ranges_m\",\"line_angles_deg\",\"reflectance_correction_db\"]"
    ",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"Ra"
    "nge-dependent and scan-angle-dependent correction of reflectance readi"
    "ng\",\"type\":\"object\",\"properties\":{\"reflectance_correction_db\":{\"type\":"
    "\"array\",\"items\":{\"type\":\"array\",\"items\":{\"type\":\"number\",\"description\""
    ":\"columns (each value corresponds to an angle)\"},\"description\":\"rows "
    "(each array corresponds to a range)\"},\"description\":\"Near range "
    "reflectance correction in dB as a function of range over angle\"},\"line"
    "_angles_deg\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\""
    "Angle [deg]\"},\"ranges_m\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"de"
    "scription\":\"Range [m]\"}},\"title\":\"Near-range reflectance correction\"}"
    ,
    /* example: */
    "{\"reflectance_correction_db\":[[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0."
    "01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0"
    ".3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01]],\"li"
    "ne_angles_deg\":[0.0,0.5,1.0,1.5,1.0,2.0,2.5,3.0,3.5,4.0],\"ranges_m\":[0"
    ".0,1.0,2.0,3.0]}"
};

// Scan pattern description
const MetaDataItemInfo RDB_RIEGL_SCAN_PATTERN = {
    /* name        */ "riegl.scan_pattern",
    /* title       */ "Scan Pattern",
    /* description */ "Scan pattern description",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"line\":{\"required\":[\"start\",\"stop\",\"increment\"],\"type\":"
    "\"object\",\"properties\":{\"program\":{\"$ref\":\"#/definitions/program\"},\"inc"
    "rement\":{\"maximum\":90.0,\"type\":\"number\",\"minimum\":0.0,\"description\":\"I"
    "ncrement of angle in SOCS [deg]\"},\"stop\":{\"maximum\":720.0,\"type\":\"numb"
    "er\",\"minimum\":0.0,\"description\":\"Stop angle in SOCS [deg]\"},\"start\":{\""
    "maximum\":360.0,\"type\":\"number\",\"minimum\":0.0,\"description\":\"Start "
    "angle in SOCS [deg]\"}},\"description\":\"Line Scan Pattern\"},\"rectangular"
    "\":{\"required\":[\"phi_start\",\"phi_stop\",\"phi_increment\",\"theta_start\",\"t"
    "heta_stop\",\"theta_increment\"],\"type\":\"object\",\"properties\":{\"program\":"
    "{\"$ref\":\"#/definitions/program\"},\"phi_start\":{\"maximum\":360.0,\"type\":\""
    "number\",\"minimum\":0.0,\"description\":\"Start phi angle in SOCS [deg]\"},\""
    "theta_stop\":{\"maximum\":180.0,\"type\":\"number\",\"minimum\":0.0,\"descriptio"
    "n\":\"Stop theta angle in SOCS [deg]\"},\"theta_increment\":{\"maximum\":90.0"
    ",\"type\":\"number\",\"minimum\":0.0,\"description\":\"Increment of theta angle"
    " in SOCS [deg]\"},\"phi_stop\":{\"maximum\":720.0,\"type\":\"number\",\"minimum\""
    ":0.0,\"description\":\"Stop phi angle in SOCS [deg]\"},\"theta_start\":{\"max"
    "imum\":180.0,\"type\":\"number\",\"minimum\":0.0,\"description\":\"Start theta "
    "angle in SOCS [deg]\"},\"phi_increment\":{\"maximum\":90.0,\"type\":\"number\","
    "\"minimum\":0.0,\"description\":\"Increment of phi angle in SOCS "
    "[deg]\"}},\"description\":\"Rectangular Field Of View Scan Pattern\"},\"segm"
    "ents\":{\"required\":[\"list\"],\"type\":\"object\",\"properties\":{\"program\":{\"$"
    "ref\":\"#/definitions/program\"},\"list\":{\"type\":\"array\",\"items\":{\"require"
    "d\":[\"start\",\"stop\",\"increment\"],\"type\":\"object\",\"properties\":{\"increme"
    "nt\":{\"maximum\":90.0,\"type\":\"number\",\"minimum\":0.0,\"description\":\"Incre"
    "ment of angle in SOCS [deg]\"},\"stop\":{\"maximum\":720.0,\"type\":\"number\","
    "\"minimum\":0.0,\"description\":\"Stop angle in SOCS [deg]\"},\"start\":{\"maxi"
    "mum\":360.0,\"type\":\"number\",\"minimum\":0.0,\"description\":\"Start angle in"
    " SOCS [deg]\"}},\"description\":\"Line Scan "
    "Segment\"}}},\"description\":\"Segmented Line Scan Pattern\"}},\"definitions"
    "\":{\"program\":{\"required\":[\"name\"],\"type\":\"object\",\"properties\":{\"laser"
    "_prr\":{\"type\":\"number\",\"minimum\":0,\"description\":\"Laser Pulse "
    "Repetition Rate [Hz]\",\"exclusiveMinimum\":false},\"name\":{\"type\":\"string"
    "\",\"description\":\"Name of measurement "
    "program\"}},\"description\":\"Measurement program\"}},\"description\":\"Scan "
    "pattern description\",\"$schema\":\"http://json-schema.org/draft-04/schema"
    "#\",\"title\":\"Scan Pattern\"}"
    ,
    /* example: */
    "{\"rectangular\":{\"program\":{\"laser_prr\":100000.0,\"name\":\"High Speed\"},\""
    "phi_start\":45.0,\"theta_stop\":130.0,\"theta_increment\":0.04,\"phi_stop\":2"
    "70.0,\"theta_start\":30.0,\"phi_increment\":0.04}}"
};

// Details about laser shot files
const MetaDataItemInfo RDB_RIEGL_SHOT_INFO = {
    /* name        */ "riegl.shot_info",
    /* title       */ "Shot Information",
    /* description */ "Details about laser shot files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"shot_file\":{\"type\":\"object\",\"required\""
    ":[\"file_extension\"],\"properties\":{\"file_uuid\":{\"type\":\"string\",\"descri"
    "ption\":\"File's Universally Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Shot file "
    "extension, without the leading dot\"}}}},\"description\":\"Details about "
    "laser shot files\",\"$schema\":\"http://json-schema.org/draft-04/schema#\","
    "\"title\":\"Shot Information\"}"
    ,
    /* example: */
    "{\"shot_file\":{\"file_uuid\":\"26a00815-67c0-4bff-8fe8-c577378fe663\",\"file"
    "_extension\":\"sodx\"}}"
};

// Point filters applied in addition to the application-defined filters
const MetaDataItemInfo RDB_RIEGL_STORED_FILTERS = {
    /* name        */ "riegl.stored_filters",
    /* title       */ "Stored Filters",
    /* description */ "Point filters applied in addition to the application-defined filters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"activated\",\"filters\"],\"$schema\":\"http://json-schema.org/"
    "draft-04/schema#\",\"description\":\"Point filters applied in addition to "
    "the application-defined filters\",\"type\":\"object\",\"properties\":{\"activa"
    "ted\":{\"type\":\"boolean\",\"description\":\"Apply ('true') or ignore "
    "('false') all filters\"},\"filters\":{\"type\":\"array\",\"items\":{\"required\":"
    "[\"activated\",\"title\",\"description\",\"filter\"],\"type\":\"object\",\"properti"
    "es\":{\"activated\":{\"type\":\"boolean\",\"description\":\"Apply ('true') or "
    "ignore ('false') this "
    "filter\"},\"filter\":{\"type\":\"string\",\"description\":\"The RDB filter "
    "string to apply (e.g. when reading points or index), details see "
    "documentation of function "
    "select()\"},\"description\":{\"type\":\"string\",\"description\":\"A brief "
    "description of the filter (e.g. for display in a "
    "tooltip)\"},\"title\":{\"type\":\"string\",\"description\":\"A short filter "
    "title (e.g. for display in a selection list)\"}},\"description\":\"Point "
    "filter definition\"},\"description\":\"List of point "
    "filters\"}},\"title\":\"Stored filters\"}"
    ,
    /* example: */
    "{\"activated\":true,\"filters\":[{\"activated\":false,\"filter\":\"riegl.mta_un"
    "certain_point == 0\",\"description\":\"Ignore points with uncertain MTA "
    "zone assignment\",\"title\":\"Ignore uncertain points from MTA resolution\""
    "},{\"activated\":false,\"filter\":\"riegl.dyntrig_uncertain_point == "
    "0\",\"description\":\"Ignore points with an echo signal amplitude below "
    "the dynamic trigger\",\"title\":\"Ignore points below dynamic trigger "
    "level\"},{\"activated\":false,\"filter\":\"riegl.point_outside_aabb_bocs == "
    "0\",\"description\":\"Ignore points that are outside the outer AABB in "
    "BOCS\",\"title\":\"Ignore points outside outer "
    "AABB\"},{\"activated\":false,\"filter\":\"riegl.point_inside_aabb_bocs == "
    "0\",\"description\":\"Ignore points that are inside the inner AABB in "
    "BOCS\",\"title\":\"Ignore points inside inner AABB\"}]}"
};

// Details of major system components like lidar sensors, cameras and navigation devices
const MetaDataItemInfo RDB_RIEGL_SYSTEM_DESCRIPTION = {
    /* name        */ "riegl.system_description",
    /* title       */ "System Description",
    /* description */ "Details of major system components like lidar sensors, cameras and navigation devices",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"$class\",\"version\",\"author\",\"timestamp\",\"system\"],\"$schem"
    "a\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"Details of"
    " major system components like lidar sensors, cameras and navigation de"
    "vices\",\"type\":\"object\",\"properties\":{\"version\":{\"type\":\"string\",\"descr"
    "iption\":\"Document format "
    "version\"},\"system\":{\"type\":\"object\",\"description\":\"The actual system "
    "description, details see documentation of RIEGL System "
    "Description\"},\"author\":{\"type\":\"string\",\"description\":\"Name of the "
    "author that created the "
    "document\"},\"timestamp\":{\"type\":\"string\",\"description\":\"Date and time "
    "of creation (e.g. 2019-06-19T13:32:10+02:00)\"},\"$class\":{\"enum\":[\"Docu"
    "ment\"],\"type\":\"string\",\"description\":\"Object class "
    "name\"}},\"title\":\"System Description\"}"
    ,
    /* example: */
    "{\"version\":\"1.2.1\",\"system\":{\"details\":\"see documentation of RIEGL "
    "System Description\"},\"author\":\"RIEGL LMS GmbH, "
    "Austria\",\"timestamp\":\"2022-09-30T11:56:26+00:00\",\"$class\":\"Document\"}"
};

// Conversion of background radiation raw values to temperatures in °C
const MetaDataItemInfo RDB_RIEGL_TEMPERATURE_CALCULATION = {
    /* name        */ "riegl.temperature_calculation",
    /* title       */ "Temperature Calculation Table",
    /* description */ "Conversion of background radiation raw values to temperatures in °C",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Conversion of background radiation raw values to "
    "temperatures in \\u00b0C\",\"definitions\":{\"conversion_table\":{\"type\":\"ob"
    "ject\",\"required\":[\"value\",\"temperature\"],\"properties\":{\"value\":{\"type\""
    ":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"LSB [1]\"},\"temperatu"
    "re\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"Temperatu"
    "re [\\u00b0C]\"}}}},\"type\":\"object\",\"properties\":{\"Si\":{\"$ref\":\"#/defini"
    "tions/conversion_table\",\"description\":\"Conversion table for Si channel"
    "\"},\"InGaAs_Si_Difference\":{\"$ref\":\"#/definitions/conversion_table\",\"de"
    "scription\":\"Conversion table for InGaAs - Si difference\"},\"InGaAs\":{\"$"
    "ref\":\"#/definitions/conversion_table\",\"description\":\"Conversion table "
    "for InGaAs channel\"}},\"$schema\":\"http://json-schema.org/draft-04/schem"
    "a#\",\"title\":\"Temperature Calculation Table\"}"
    ,
    /* example: */
    "{\"Si\":{\"value\":[0.0,64.00097659230323,128.0019531846065,192.0029297769"
    "097,256.0039063692129,320.00488296151616,384.0058595538194,448.0068361"
    "461226,512.0078127384259],\"temperature\":[546.300048828125,548.81640512"
    "12026,551.3143938500972,554.0144257850053,556.604252334815,559.2124464"
    "488079,561.8022729986177,564.4104671126105,567.0002936624203]},\"InGaAs"
    "_Si_Difference\":{\"value\":[1000.0,1100.090029602954,1200.04425183874,13"
    "00.1342814416948,1400.0885036774805,1500.0427259132668,1600.1327555162"
    "209,1700.0869777520065,1800.0411999877924],\"temperature\":[1749.9771111"
    "17893,1749.977111117893,1749.977111117893,1749.977111117893,1749.97711"
    "1117893,1749.977111117893,1744.7813348796044,1681.9971312601092,1622.3"
    "944822534868]},\"InGaAs\":{\"value\":[0.0,64.00097659230323,128.0019531846"
    "065,192.0029297769097,256.0039063692129,320.00488296151616,384.0058595"
    "538194,448.0068361461226,512.0078127384259],\"temperature\":[307.2219672"
    "2535614,309.1153478247277,311.1188086915047,313.10025350480055,315.213"
    "7946389828,317.2172555057597,319.2207163725366,321.2021611858325,323.3"
    "157023200148]}}"
};

// Base of timestamps (epoch)
const MetaDataItemInfo RDB_RIEGL_TIME_BASE = {
    /* name        */ "riegl.time_base",
    /* title       */ "Time Base",
    /* description */ "Base of timestamps (epoch)",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"epoch\",\"source\"],\"$schema\":\"http://json-schema.org/draft"
    "-04/schema#\",\"description\":\"Base of timestamps (epoch)\",\"type\":\"object"
    "\",\"properties\":{\"source\":{\"enum\":[\"unknown\",\"RTC\",\"GNSS\"],\"type\":\"stri"
    "ng\",\"description\":\"Timestamp "
    "source\"},\"epoch\":{\"type\":\"string\",\"description\":\"Date and time of "
    "timestamp '0' as proposed by RFC 3339 (e.g. 2015-10-27T00:00:00+01:00)"
    ".\"},\"system\":{\"enum\":[\"unknown\",\"UTC\",\"GPS\"],\"type\":\"string\",\"descript"
    "ion\":\"Time system (time standard)\"}},\"title\":\"Time Base\"}"
    ,
    /* example: */
    "{\"source\":\"GNSS\",\"epoch\":\"2015-10-27T00:00:00+00:00\",\"system\":\"UTC\"}"
};

// Details about position+orientation files
const MetaDataItemInfo RDB_RIEGL_TRAJECTORY_INFO = {
    /* name        */ "riegl.trajectory_info",
    /* title       */ "Trajectory Information",
    /* description */ "Details about position+orientation files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"time_interval\",\"navigation_frame\"],\"$schema\":\"http://jso"
    "n-schema.org/draft-04/schema#\",\"description\":\"Details about "
    "position+orientation files\",\"type\":\"object\",\"properties\":{\"device\":{\"t"
    "ype\":\"string\",\"description\":\"Navigation device, e.g. "
    "name/type/serial\"},\"settings\":{\"type\":\"string\",\"description\":\"Settings"
    " used to calculate the trajectory (descriptive text)\"},\"time_interval\""
    ":{\"required\":[\"minimum\",\"average\",\"maximum\",\"std_dev\"],\"type\":\"object\""
    ",\"properties\":{\"maximum\":{\"type\":\"number\",\"description\":\"Maximum time "
    "interval [s]\"},\"minimum\":{\"type\":\"number\",\"description\":\"Minimum time "
    "interval [s]\"},\"std_dev\":{\"type\":\"number\",\"description\":\"Standard "
    "deviation of intervals "
    "[s]\"},\"average\":{\"type\":\"number\",\"description\":\"Average time interval "
    "[s]\"}},\"description\":\"Time interval "
    "statistics\"},\"software\":{\"type\":\"string\",\"description\":\"Software that "
    "calculated the trajectory (this may be the same or different software "
    "than the one that created the file)\"},\"field_of_application\":{\"enum\":["
    "\"unknown\",\"SLS\",\"TLS\",\"KLS\",\"MLS\",\"ULS\",\"ALS\",\"BLS\",\"ILS\"],\"type\":\"str"
    "ing\",\"description\":\"Field of application\"},\"navigation_frame\":{\"enum\":"
    "[\"unknown\",\"NED\",\"ENU\"],\"type\":\"string\",\"description\":\"Navigation "
    "frame (NED: North-East-Down, ENU: "
    "East-North-Up)\"},\"project\":{\"type\":\"string\",\"description\":\"Project "
    "name\"},\"location\":{\"type\":\"string\",\"description\":\"Project location, "
    "e.g. "
    "city/state/country\"},\"company\":{\"type\":\"string\",\"description\":\"Company"
    " name\"}},\"title\":\"Trajectory Information\"}"
    ,
    /* example: */
    "{\"device\":\"IMU Model 12/1, Serial# 12345\",\"settings\":\"default\",\"time_i"
    "nterval\":{\"maximum\":0.005004883,\"minimum\":0.00500032,\"std_dev\":5.51e-0"
    "7,\"average\":0.00500053},\"software\":\"Navigation Software XYZ\",\"field_of"
    "_application\":\"MLS\",\"navigation_frame\":\"NED\",\"project\":\"Campaign "
    "3\",\"location\":\"Horn\",\"company\":\"RIEGL LMS\"}"
};

// Trigger-Timestamping-Unit/IP configuration
const MetaDataItemInfo RDB_RIEGL_TTIP_CONFIGURATION = {
    /* name        */ "riegl.ttip_configuration",
    /* title       */ "TTIP Configuration",
    /* description */ "Trigger-Timestamping-Unit/IP configuration",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"ttip_version\",\"num_channel\",\"ext_channel\",\"ext_signal\",\""
    "ext_delay\",\"ext_subdivider\",\"ext_bitmask\",\"dmi_incr\",\"dmi_min_time\",\"d"
    "mi_max_time\",\"dmi_dist_per_tick\",\"channel\",\"output_descr\",\"input_descr"
    "\",\"output_usage\",\"input_usage\",\"out_polarity\",\"out_duration\",\"out_inte"
    "rval\",\"out_delay\",\"out_num_pulses\",\"in_polarity\",\"in_min_duration\",\"in"
    "_max_duration\",\"in_max_delay\"],\"$schema\":\"http://json-schema.org/draft"
    "-04/schema#\",\"description\":\"Trigger-Timestamping-Unit/IP configuration"
    "\",\"type\":\"object\",\"properties\":{\"ext_subdivider\":{\"type\":\"integer\",\"mi"
    "nimum\":0,\"description\":\"reduces the frequency, default "
    "1\"},\"out_duration\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"output"
    " pulse duration [0.1 "
    "msec]\"},\"output_descr\":{\"type\":\"string\",\"description\":\"descriptive str"
    "ing\"},\"out_num_pulses\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"nu"
    "mber of output pulses to be generated, 0 .. infinite\"},\"in_min_duratio"
    "n\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"input signals with "
    "smaller pulse durations are ignored [0.1 msec]\"},\"num_channel\":{\"type\""
    ":\"integer\",\"minimum\":0,\"description\":\"number of input/output channels\""
    "},\"input_usage\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"0 .. "
    "deactivated, 1 .. just detecting and timestamping\"},\"dmi_dist_per_tick"
    "\":{\"type\":\"number\",\"description\":\"dmi, distance per tick, just "
    "informative "
    "[m]\"},\"input_descr\":{\"type\":\"string\",\"description\":\"descriptive string"
    "\"},\"in_max_delay\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"maximum"
    " delay to output pulse before fake event is generated [0.1 msec], zero"
    " indicates that no fake events are generated\"},\"dmi_max_time\":{\"type\":"
    "\"integer\",\"minimum\":0,\"description\":\"dmi, maximum time interval "
    "between trigger events [0.1 "
    "msec]\"},\"in_polarity\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"0 "
    ".. positive edge, 1 .. negative "
    "edge\"},\"ext_signal\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"0 .. "
    "use input signal, 1 .. use output signal of channel\"},\"dmi_min_time\":{"
    "\"type\":\"integer\",\"minimum\":0,\"description\":\"dmi, minimum time interval"
    " between trigger events [0.1 "
    "msec]\"},\"channel\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"ID of "
    "input/output channel\"},\"out_polarity\":{\"type\":\"integer\",\"minimum\":0,\"d"
    "escription\":\"0 .. positive edge, 1 .. negative edge\"},\"in_max_duration"
    "\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"stops measurement of "
    "pulse duration of input signal [0.1 msec]\"},\"out_interval\":{\"type\":\"in"
    "teger\",\"minimum\":0,\"description\":\"output pulse interval [0.1 "
    "msec]\"},\"ext_channel\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"ID "
    "of channel used as external trigger input, 32 indicates "
    "none\"},\"dmi_incr\":{\"type\":\"integer\",\"description\":\"dmi, increment in t"
    "icks\"},\"ttip_version\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"fol"
    "lowing main.sub.ss.sss\"},\"out_delay\":{\"type\":\"integer\",\"minimum\":0,\"de"
    "scription\":\"output pulse initial delay after start [0.1 msec]\"},\"ext_b"
    "itmask\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"defines which of "
    "the internal pulse generators are to be started\"},\"output_usage\":{\"typ"
    "e\":\"integer\",\"minimum\":0,\"description\":\"0 .. no output, 1 .. output "
    "derived from internal clock, 2 .. output derived from dmi, 3 .. output"
    " derived from external signal, 4 .. output static low, 5 .. output "
    "static high\"},\"ext_delay\":{\"type\":\"integer\",\"minimum\":0,\"description\":"
    "\"external trigger, time delay [0.1 msec]\"}},\"title\":\"TTIP "
    "Configuration\"}"
    ,
    /* example: */
    "{\"ext_subdivider\":1,\"out_duration\":300,\"output_descr\":\"Port 1 - Trigge"
    "r\",\"out_num_pulses\":1,\"in_min_duration\":0,\"num_channel\":9,\"input_usage"
    "\":1,\"dmi_dist_per_tick\":0.0,\"input_descr\":\"Port 1 - Exposure\",\"in_max_"
    "delay\":9990,\"dmi_max_time\":0,\"in_polarity\":0,\"ext_signal\":0,\"dmi_min_t"
    "ime\":0,\"channel\":0,\"out_polarity\":0,\"in_max_duration\":10000,\"out_inter"
    "val\":10000,\"ext_channel\":32,\"dmi_incr\":0,\"ttip_version\":1,\"out_delay\":"
    "0,\"ext_bitmask\":0,\"output_usage\":1,\"ext_delay\":0}"
};

// Details about vertex file
const MetaDataItemInfo RDB_RIEGL_VERTEX_INFO = {
    /* name        */ "riegl.vertex_info",
    /* title       */ "Vertex Information",
    /* description */ "Details about vertex file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"vertex_file\":{\"type\":\"object\",\"require"
    "d\":[\"file_extension\"],\"properties\":{\"file_uuid\":{\"type\":\"string\",\"desc"
    "ription\":\"File's Universally Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Vertex file "
    "extension, without the leading dot\"}}}},\"description\":\"Details about "
    "vertex file\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"titl"
    "e\":\"Vertex Information\"}"
    ,
    /* example: */
    "{\"vertex_file\":{\"file_uuid\":\"51534d95-d71f-4f36-ae1a-3e63a21fd1c7\",\"fi"
    "le_extension\":\"vtx\"}}"
};

// Details about the voxels contained in the file
const MetaDataItemInfo RDB_RIEGL_VOXEL_INFO = {
    /* name        */ "riegl.voxel_info",
    /* title       */ "Voxel Information",
    /* description */ "Details about the voxels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"definitions\":{\"voxel_size_cubic\":{\"type\":\"number\",\"$ref\":\"#/definiti"
    "ons/edge_length\"},\"voxel_size\":{\"minItems\":3,\"type\":\"array\",\"items\":{\""
    "$ref\":\"#/definitions/edge_length\"},\"description\":\"Size of voxels.\",\"ma"
    "xItems\":3},\"voxel_origin_point\":{\"minItems\":3,\"type\":\"array\",\"items\":{"
    "\"type\":\"number\"},\"description\":\"Origin point for all voxel indices in "
    "voxel CRS.\",\"maxItems\":3},\"shape_thresholds\":{\"type\":\"object\",\"propert"
    "ies\":{\"line\":{\"minimum\":1,\"type\":\"number\",\"exclusiveMinimum\":true,\"des"
    "cription\":\"If the biggest eigenvalue is bigger than the median "
    "eigenvalue * line_threshold, the voxel is considered a "
    "line.\"},\"plane\":{\"minimum\":0,\"exclusiveMaximum\":true,\"description\":\"If"
    " the smallest eigenvalue is smaller than the median eigenvalue * "
    "plane_threshold, the voxel is considered a plane.\",\"maximum\":1,\"type\":"
    "\"number\",\"exclusiveMinimum\":true}},\"required\":[\"plane\",\"line\"],\"descri"
    "ption\":\"Thresholds used to compute the voxel's shape_id value.\"},\"edge"
    "_length\":{\"minimum\":0,\"type\":\"number\",\"exclusiveMinimum\":true,\"descrip"
    "tion\":\"Length of voxel edge [m].\"},\"voxel_origin_enum\":{\"enum\":[\"cente"
    "r\",\"corner\"],\"default\":\"corner\",\"description\":\"Defines whether the "
    "voxel's center or a corner is placed on CRS origin <tt>(0/0/0)</tt>.\"}"
    ",\"voxel_type\":{\"enum\":[\"center\",\"centroid\",\"index\"],\"default\":\"centroi"
    "d\",\"description\":\"Whether a point in a voxel represents its center or "
    "its centroid. If type is <tt>index</tt> there is no point but only an "
    "integer voxel index.\"}},\"description\":\"Details about the voxels "
    "contained in the file\",\"type\":\"object\",\"oneOf\":[{\"additionalProperties"
    "\":false,\"required\":[\"size\",\"voxel_origin\",\"voxel_type\"],\"properties\":{"
    "\"voxel_type\":{\"$ref\":\"#/definitions/voxel_type\"},\"voxel_origin\":{\"$ref"
    "\":\"#/definitions/voxel_origin_enum\"},\"size\":{\"oneOf\":[{\"$ref\":\"#/defin"
    "itions/voxel_size\"},{\"$ref\":\"#/definitions/voxel_size_cubic\"}],\"descri"
    "ption\":\"Size of voxels in file coordinate system.\"},\"shape_thresholds\""
    ":{\"$ref\":\"#/definitions/shape_thresholds\"}}},{\"additionalProperties\":f"
    "alse,\"required\":[\"reference_point\",\"size_llcs\",\"size\",\"voxel_origin\",\""
    "voxel_type\"],\"properties\":{\"reference_point\":{\"minItems\":2,\"type\":\"arr"
    "ay\",\"items\":{\"maximum\":180,\"type\":\"number\",\"minimum\":-180},\"descriptio"
    "n\":\"Point in WGS84 geodetic decimal degree (EPSG:4326) that was used "
    "to compute the projection distortion parameters. The coefficient order"
    " is latitude, longitude. Only voxels with corresponding geo_tag, "
    "voxel_size and reference_point can be reliably processed together. "
    "This entry is available for voxel files in projected CRS only.\",\"maxIt"
    "ems\":2},\"size\":{\"$ref\":\"#/definitions/voxel_size\",\"description\":\"Size "
    "of voxels in file coordinate system.\"},\"shape_thresholds\":{\"$ref\":\"#/d"
    "efinitions/shape_thresholds\"},\"size_llcs\":{\"$ref\":\"#/definitions/voxel"
    "_size\",\"description\":\"Size of voxels in a locally levelled cartesian "
    "coordinate system (xyz). This is only used for voxels based on a map p"
    "rojection.\"},\"voxel_origin\":{\"oneOf\":[{\"$ref\":\"#/definitions/voxel_ori"
    "gin_enum\"},{\"$ref\":\"#/definitions/voxel_origin_point\",\"description\":\"T"
    "he base point of the voxel grid. Used together with "
    "<tt>voxel_size</tt> and <tt>voxel_index</tt> to compute actual point c"
    "oordinates.\"}]},\"voxel_type\":{\"$ref\":\"#/definitions/voxel_type\"}}}],\"$"
    "schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Voxel "
    "Information\"}"
    ,
    /* example: */
    "{\"reference_point\":[48,16],\"size\":[0.5971642834779395,0.59716428347793"
    "95,0.5143705304787237],\"shape_thresholds\":{\"line\":6,\"plane\":0.16},\"siz"
    "e_llcs\":[0.5156575252891171,0.5130835356683303,0.5143705304787237],\"vo"
    "xel_origin\":\"corner\",\"voxel_type\":\"centroid\"}"
};

// Settings for waveform averaging
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS = {
    /* name        */ "riegl.waveform_averaging_settings",
    /* title       */ "Waveform Averaging Settings",
    /* description */ "Settings for waveform averaging",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"num_shots\",\"mta_zone\"],\"$schema\":\"http://json-schema.org"
    "/draft-04/schema#\",\"description\":\"Settings for waveform averaging\",\"ty"
    "pe\":\"object\",\"properties\":{\"trim\":{\"maximum\":0.5,\"type\":\"number\",\"mini"
    "mum\":0,\"description\":\"Percentage for robust averaging.\",\"default\":0},\""
    "mta_zone\":{\"type\":\"integer\",\"minimum\":1,\"description\":\"Fixed MTA zone "
    "for averaging.\"},\"num_shots\":{\"type\":\"integer\",\"minimum\":1,\"descriptio"
    "n\":\"Number of consecutive shots to be used for "
    "averaging.\"}},\"title\":\"Waveform Averaging Settings\"}"
    ,
    /* example: */
    "{\"trim\":0.05,\"mta_zone\":1,\"num_shots\":7}"
};

// Details about waveform files
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_INFO = {
    /* name        */ "riegl.waveform_info",
    /* title       */ "Waveform Information",
    /* description */ "Details about waveform files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"De"
    "tails about waveform files\",\"type\":\"object\",\"properties\":{\"range_offse"
    "t_m\":{\"type\":\"number\",\"description\":\"Calibrated device specific range "
    "offset for waveform analysis by system response fitting in meters.\"},\""
    "sample_block_file\":{\"type\":\"object\",\"properties\":{\"file_uuid\":{\"type\":"
    "\"string\",\"description\":\"File's Universally Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Sample block "
    "file extension, without the leading dot\"}},\"required\":[\"file_extension"
    "\"]},\"sample_data_files\":{\"type\":\"array\",\"items\":{\"type\":\"object\",\"prop"
    "erties\":{\"channel_name\":{\"type\":\"string\",\"description\":\"Sample block "
    "channel name\"},\"channel\":{\"minimum\":0,\"exclusiveMaximum\":false,\"descri"
    "ption\":\"Sample block channel number (255 = invalid)\",\"maximum\":255,\"ty"
    "pe\":\"integer\",\"exclusiveMinimum\":false},\"file_uuid\":{\"type\":\"string\",\""
    "description\":\"File's Universally Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Sample data "
    "file extension, without the leading dot\"},\"laser_wavelength\":{\"minimum"
    "\":0,\"type\":\"number\",\"exclusiveMinimum\":false,\"description\":\"Laser "
    "wavelength in meters (0 = unknown)\"},\"sample_interval\":{\"minimum\":0,\"t"
    "ype\":\"number\",\"exclusiveMinimum\":false,\"description\":\"Sampling "
    "interval in seconds\"},\"sample_bits\":{\"minimum\":0,\"exclusiveMaximum\":fa"
    "lse,\"description\":\"Bitwidth of samples (e.g. 10 bit, 12 bit)\",\"maximum"
    "\":32,\"type\":\"integer\",\"exclusiveMinimum\":false},\"delta_st\":{\"type\":\"nu"
    "mber\",\"description\":\"reserved\"}},\"required\":[\"channel\",\"channel_name\","
    "\"sample_interval\",\"sample_bits\",\"laser_wavelength\",\"delta_st\",\"file_ex"
    "tension\"]}},\"range_offset_waveform_samples_m\":{\"type\":\"number\",\"descri"
    "ption\":\"Calibrated device specific range offset for waveform samples "
    "in meters.\"}},\"required\":[\"sample_block_file\",\"sample_data_files\"],\"ti"
    "tle\":\"Waveform Information\"}"
    ,
    /* example: */
    "{\"range_offset_m\":3.1415,\"sample_block_file\":{\"file_uuid\":\"93a03615-66"
    "c0-4bea-8ff8-c577378fe660\",\"file_extension\":\"sbx\"},\"sample_data_files\""
    ":[{\"channel_name\":\"high_power\",\"channel\":0,\"laser_wavelength\":0,\"file_"
    "extension\":\"sp0\",\"file_uuid\":\"da084413-e3e8-4655-a122-071de8490d8e\",\"s"
    "ample_interval\":1.00503e-09,\"sample_bits\":12,\"delta_st\":0},{\"channel_n"
    "ame\":\"low_power\",\"channel\":1,\"laser_wavelength\":0,\"file_extension\":\"sp"
    "1\",\"file_uuid\":\"93585b5e-5ea9-43a1-947b-e7ba3be642d2\",\"sample_interval"
    "\":1.00503e-09,\"sample_bits\":12,\"delta_st\":0},{\"channel_name\":\"wwf\",\"ch"
    "annel\":5,\"laser_wavelength\":0,\"file_extension\":\"sp5\",\"file_uuid\":\"9d22"
    "98c4-1036-464f-b5cb-1cf8e517f3a0\",\"sample_interval\":1.00503e-09,\"sampl"
    "e_bits\":12,\"delta_st\":0}],\"range_offset_waveform_samples_m \":7.283}"
};

// Scanner settings for waveform output
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_SETTINGS = {
    /* name        */ "riegl.waveform_settings",
    /* title       */ "Waveform Settings",
    /* description */ "Scanner settings for waveform output",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"array\",\"items\":{\"type\":\"object\",\"required\":[\"sbl_name\",\"enabl"
    "ed\",\"channel_idx_mask\"],\"properties\":{\"pass_dev_greater\":{\"type\":\"inte"
    "ger\",\"description\":\"Threshold for deviation greater than "
    "[1]\"},\"smart_enabled\":{\"type\":\"boolean\",\"description\":\"Smart waveform "
    "output "
    "enabled\"},\"pass_rng_greater\":{\"type\":\"number\",\"description\":\"Threshold"
    " for range greater than "
    "[m]\"},\"channel_idx_mask\":{\"type\":\"integer\",\"description\":\"Bit mask for"
    " channels which belong to sbl_name: Channel 0 = Bit0, Channel 1 = "
    "Bit1, ...\"},\"pass_ampl_less\":{\"type\":\"number\",\"description\":\"Threshold"
    " for amplitude less than "
    "[dB]\"},\"pass_dev_less\":{\"type\":\"integer\",\"description\":\"Threshold for "
    "deviation less than "
    "[1]\"},\"pass_ampl_greater\":{\"type\":\"number\",\"description\":\"Threshold "
    "for amplitude greater than "
    "[dB]\"},\"enabled\":{\"type\":\"boolean\",\"description\":\"Waveform output "
    "enabled\"},\"sbl_name\":{\"type\":\"string\",\"description\":\"Name of sample "
    "block, e.g.: wfm, "
    "wwf\"},\"pass_rng_less\":{\"type\":\"number\",\"description\":\"Threshold for "
    "range less than "
    "[m]\"},\"logic_expression\":{\"type\":\"string\",\"description\":\"Logic "
    "expression of smart waveforms filter\"}}},\"description\":\"Scanner "
    "settings for waveform output\",\"$schema\":\"http://json-schema.org/draft-"
    "04/schema#\",\"title\":\"Waveform Settings\"}"
    ,
    /* example: */
    "[{\"smart_enabled\":true,\"pass_rng_greater\":9.27,\"pass_ampl_less\":5.0,\"c"
    "hannel_idx_mask\":11,\"pass_ampl_greater\":1.0,\"enabled\":true,\"sbl_name\":"
    "\"wfm\",\"pass_rng_less\":13.11},{\"channel_idx_mask\":32,\"enabled\":false,\"s"
    "bl_name\":\"wwf\"}]"
};

// Window analysis data estimated from scandata and resulting filter parameters
const MetaDataItemInfo RDB_RIEGL_WINDOW_ANALYSIS = {
    /* name        */ "riegl.window_analysis",
    /* title       */ "Window Analysis",
    /* description */ "Window analysis data estimated from scandata and resulting filter parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"result\",\"filter\",\"settings\"],\"$schema\":\"http://json-sche"
    "ma.org/draft-04/schema#\",\"description\":\"Window analysis data estimated"
    " from scandata and resulting filter parameters\",\"type\":\"object\",\"prope"
    "rties\":{\"filter\":{\"type\":\"object\",\"required\":[\"angle\",\"range_min\",\"ran"
    "ge_max\",\"amplitude_max\"],\"properties\":{\"range_min\":{\"type\":\"array\",\"it"
    "ems\":{\"type\":\"number\"},\"description\":\"[m]\"},\"angle\":{\"type\":\"array\",\"i"
    "tems\":{\"type\":\"number\"},\"description\":\"[deg]\"},\"range_max\":{\"type\":\"ar"
    "ray\",\"items\":{\"type\":\"number\"},\"description\":\"[m]\"},\"amplitude_max\":{\""
    "type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"[dB]\"}}},\"setti"
    "ngs\":{\"type\":\"object\",\"required\":[\"range\",\"amplitude\"],\"properties\":{\""
    "amplitude\":{\"type\":\"object\",\"required\":[\"sigma_factor\",\"additive_value"
    "\"],\"properties\":{\"additive_value\":{\"type\":\"number\"},\"sigma_factor\":{\"t"
    "ype\":\"number\"}}},\"range\":{\"type\":\"object\",\"required\":[\"sigma_factor\",\""
    "additive_value\"],\"properties\":{\"additive_value\":{\"type\":\"number\"},\"sig"
    "ma_factor\":{\"type\":\"number\"}}}}},\"result\":{\"type\":\"object\",\"required\":"
    "[\"angle\",\"range_mean\",\"range_sigma\",\"amplitude_mean\",\"amplitude_sigma\""
    ",\"amplitude_offset\"],\"properties\":{\"amplitude_offset\":{\"type\":\"array\","
    "\"items\":{\"type\":\"number\"},\"description\":\"[dB]\"},\"timestamp\":{\"type\":\"a"
    "rray\",\"items\":{\"type\":\"number\"},\"description\":\"[s]\"},\"range_mean\":{\"ty"
    "pe\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"[m]\"},\"range_sigm"
    "a\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"[m]\"},\"ang"
    "le\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"[deg]\"},\""
    "amplitude_mean\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description"
    "\":\"[dB]\"},\"amplitude_sigma\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},"
    "\"description\":\"[dB]\"}}}},\"title\":\"Window Analysis\"}"
    ,
    /* example: */
    "{\"filter\":{\"range_min\":[-0.208,-0.21,-0.212,-0.214,-0.216,-0.218,-0.21"
    "9,-0.221,-0.223,-0.225,-0.227],\"angle\":[14.9,15.0,15.1,15.2,15.3,15.4,"
    "15.5,15.6,15.7,15.8,15.9],\"range_max\":[0.424,0.425,0.426,0.427,0.428,0"
    ".428,0.429,0.43,0.431,0.431,0.432],\"amplitude_max\":[8.04,8.01,7.99,7.9"
    "6,7.93,7.9,7.88,7.85,7.83,7.8,7.78]},\"settings\":{\"amplitude\":{\"additiv"
    "e_value\":1.0,\"sigma_factor\":4},\"range\":{\"additive_value\":0.1,\"sigma_fa"
    "ctor\":8}},\"result\":{\"amplitude_offset\":[1.9,1.9],\"timestamp\":[408.4441"
    ",411.4443],\"range_mean\":[0.1105621,0.1079564,0.1087088,0.1067261,0.105"
    "4582,0.1090412,0.102871,0.1019044,0.1051523,0.1058445,0.1031261],\"rang"
    "e_sigma\":[0.01869652,0.02151435,0.01747969,0.01918765,0.01945776,0.019"
    "34862,0.01955329,0.02225589,0.02229977,0.01899122,0.02009433],\"angle\":"
    "[14.9,15.0,15.1,15.2,15.3,15.4,15.5,15.6,15.7,15.8,15.9],\"amplitude_me"
    "an\":[5.347396,5.263155,5.224655,5.179926,5.097782,5.116479,5.051756,4."
    "983473,5.007885,5.002441,4.982],\"amplitude_sigma\":[0.4272844,0.4298479"
    ",0.4236816,0.4283583,0.4362353,0.4315141,0.4373984,0.4472798,0.4346001"
    ",0.4345487,0.4540681]}}"
};

// Correction parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_WINDOW_ECHO_CORRECTION = {
    /* name        */ "riegl.window_echo_correction",
    /* title       */ "Window Echo Correction",
    /* description */ "Correction parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"amplitude\",\"range\",\"slices\"],\"$schema\":\"http://json-sche"
    "ma.org/draft-04/schema#\",\"description\":\"Correction parameters for "
    "window glass echoes\",\"type\":\"object\",\"properties\":{\"amplitude\":{\"requi"
    "red\":[\"minimum\",\"maximum\",\"entries\"],\"type\":\"object\",\"properties\":{\"ma"
    "ximum\":{\"type\":\"number\",\"minimum\":0.0,\"description\":\"Maximum amplitude"
    " in "
    "dB\"},\"minimum\":{\"type\":\"number\",\"minimum\":0.0,\"description\":\"Minimum "
    "amplitude in "
    "dB\"},\"entries\":{\"type\":\"integer\",\"minimum\":1,\"description\":\"Number of "
    "amplitude entries\"}},\"description\":\"Amplitude axis of correction table"
    "\"},\"range\":{\"required\":[\"minimum\",\"maximum\",\"entries\"],\"type\":\"object\""
    ",\"properties\":{\"maximum\":{\"maximum\":2.0,\"type\":\"number\",\"minimum\":-2.0"
    ",\"description\":\"Maximum range in m\"},\"minimum\":{\"maximum\":2.0,\"type\":\""
    "number\",\"minimum\":-2.0,\"description\":\"Minimum range in "
    "m\"},\"entries\":{\"type\":\"integer\",\"minimum\":1,\"description\":\"Number of "
    "range entries\"}},\"description\":\"Range axis of correction table\"},\"slic"
    "es\":{\"type\":\"array\",\"items\":{\"required\":[\"amplitude\",\"table\"],\"type\":\""
    "object\",\"properties\":{\"table\":{\"minItems\":1,\"type\":\"array\",\"items\":{\"m"
    "inItems\":1,\"type\":\"array\",\"items\":{\"minItems\":3,\"type\":\"array\",\"items\""
    ":{\"type\":\"number\",\"description\":\"Table cell (item 0: amplitude in dB, "
    "1: range in m, 2: flags)\"},\"description\":\"Table column (= range "
    "axis)\",\"maxItems\":3},\"description\":\"Table row (= amplitude "
    "axis)\"},\"description\":\"Correction table (dimension defined by the "
    "'amplitude' and 'range' "
    "objects)\"},\"amplitude\":{\"type\":\"number\",\"description\":\"Window echo "
    "amplitude of slice in dB\"}},\"description\":\"Window echo correction "
    "parameter slice\"}}},\"title\":\"Window Echo Correction\"}"
    ,
    /* example: */
    "{\"amplitude\":{\"maximum\":20,\"minimum\":2,\"entries\":128},\"range\":{\"maximu"
    "m\":1.5060822940732335,\"minimum\":-1.5060822940732335,\"entries\":128},\"sl"
    "ices\":[{\"table\":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]],\"amplitude\":1.5"
    "},{\"table\":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]],\"amplitude\":2.0}]}"
};

// Table of all meta data item details records
const MetaDataItemInfo* const RDB_META_DATA_ITEMS[] = {
    &RDB_RIEGL_ANGULAR_NOTCH_FILTER,
    &RDB_RIEGL_ATMOSPHERE,
    &RDB_RIEGL_BEAM_GEOMETRY,
    &RDB_RIEGL_CONTROL_OBJECT_CATALOG,
    &RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE,
    &RDB_RIEGL_DETECTION_PROBABILITY,
    &RDB_RIEGL_DEVICE,
    &RDB_RIEGL_DEVICE_GEOMETRY,
    &RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL,
    &RDB_RIEGL_DEVICE_OUTPUT_LIMITS,
    &RDB_RIEGL_DEVICES,
    &RDB_RIEGL_DYNTRIG,
    &RDB_RIEGL_ECHO_INFO,
    &RDB_RIEGL_EXPONENTIAL_DECOMPOSITION,
    &RDB_RIEGL_GAUSSIAN_DECOMPOSITION,
    &RDB_RIEGL_GEO_TAG,
    &RDB_RIEGL_GEOMETRIC_SCALE_FACTOR,
    &RDB_RIEGL_GEOREFERENCING_PARAMETERS,
    &RDB_RIEGL_ITEM_NAMES,
    &RDB_RIEGL_LICENSES,
    &RDB_RIEGL_MTA_SETTINGS,
    &RDB_RIEGL_NEAR_RANGE_CORRECTION,
    &RDB_RIEGL_NOISE_ESTIMATES,
    &RDB_RIEGL_NOTCH_FILTER,
    &RDB_RIEGL_PIXEL_INFO,
    &RDB_RIEGL_PLANE_PATCH_MATCHING,
    &RDB_RIEGL_PLANE_PATCH_STATISTICS,
    &RDB_RIEGL_PLANE_SLOPE_CLASS_INFO,
    &RDB_RIEGL_POINT_ATTRIBUTE_GROUPS,
    &RDB_RIEGL_POINTCLOUD_INFO,
    &RDB_RIEGL_POSE_ESTIMATION,
    &RDB_RIEGL_POSE_SENSORS,
    &RDB_RIEGL_PULSE_POSITION_MODULATION,
    &RDB_RIEGL_RANGE_STATISTICS,
    &RDB_RIEGL_RECEIVER_INTERNALS,
    &RDB_RIEGL_REFLECTANCE_CALCULATION,
    &RDB_RIEGL_REFLECTANCE_CORRECTION,
    &RDB_RIEGL_SCAN_PATTERN,
    &RDB_RIEGL_SHOT_INFO,
    &RDB_RIEGL_STORED_FILTERS,
    &RDB_RIEGL_SYSTEM_DESCRIPTION,
    &RDB_RIEGL_TEMPERATURE_CALCULATION,
    &RDB_RIEGL_TIME_BASE,
    &RDB_RIEGL_TRAJECTORY_INFO,
    &RDB_RIEGL_TTIP_CONFIGURATION,
    &RDB_RIEGL_VERTEX_INFO,
    &RDB_RIEGL_VOXEL_INFO,
    &RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS,
    &RDB_RIEGL_WAVEFORM_INFO,
    &RDB_RIEGL_WAVEFORM_SETTINGS,
    &RDB_RIEGL_WINDOW_ANALYSIS,
    &RDB_RIEGL_WINDOW_ECHO_CORRECTION
};
const std::size_t RDB_META_DATA_ITEM_COUNT(
    sizeof(RDB_META_DATA_ITEMS) / sizeof(RDB_META_DATA_ITEMS[0])
);
const std::vector<const MetaDataItemInfo*> RDB_META_DATA_ITEMS_VECTOR(
    RDB_META_DATA_ITEMS, RDB_META_DATA_ITEMS + RDB_META_DATA_ITEM_COUNT
);

}}} // namespace riegl::rdb::pointcloud

#endif // RDB_354CFFB3_BDAA_4E38_98C8_9C09D0C0AD87
